      *****************************************************************
      * File:      IF2295.CBL
      * Author:    Laura Dittamo
      * Date:      10/05/95
      * Purpose:
      *    This routine validates Price Election.
      *
      *    MALTING BARLEY - Type Practice Options A and B
      *    - Price Election must be .34 -  .50 for Option A
      *    - Price Election must be .01 - 2.00 for Option B
      *
      *    GRP
      *    - Price Election must equal 1.0
      *
      *    AVOCADOS (Ins Plan 46)
      *    - Price Election must equal zero.
      *
      *    PROCESSING FOR FLORIDA FRUIT & TROPICAL TREES (Ins Plan 40)
      *    - CAT (Coverage Level 'C') records must have Price Election
      *      = 60% of Reference Maximum Price (ADM1 - Ref Max Price)
      *    - Buyup (Coverage Level 'L' or 'A') records must have Price
      *      Election = Reference Maximum Price.
      *
      *    **** ALL OTHER PLANS AND CROPS ****
      *    LOOKUP ADM4 RECORD AND EDIT PRICE ELECTION BASED ON SUFFIX
      *
      *    CONTRACT PRICE CROPS
      *    Price Election will be determined on an individual producer
      *    basis.  ADM4 record will contain "CP" in the contract price
      *    code field and the suffix code will be 9.  Accept the input
      *    Price election.  Price Election % = 100%
      *
      *    PROCESSING FOR IP (Ins Plan 42)
      *    - Price Election should equal 100% of IP Pre-Sales Price
      *    - ADM4 SUFFIX CODE MUST = 7
      *
      *    PROCESSING FOR CRC (Ins Plan 44)
      *    - Price Election should equal 100% of the Spring Market Price
      *    - ADM4 SUFFIX CODE MUST = 8
      *
      *    PROCESSING FOR RA (Ins Plan 25)
      *    - Price Election should equal 100% of the Projected Harvest Price
      *    - ADM4 SUFFIX CODE MUST = 3
      *
      *    PROCESSING FOR PEANUTS (Ins Plan 10)
      *    If Quota
      *    - Price Election should equal 60-100% of the Quota Price.
      *    - ADM4 SUFFIX CODE MUST = 4
      *    If Non-Quota
      *    - Price Election should equal 60-100% of the Non-Quota Price.
      *    - ADM4 SUFFIX CODE MUST = 4
      *
      *    PROCESSING FOR QUOTA TOBACCO (Ins Plan 70)
      *    - Price Election should equal the Support Price.
      *    - ADM4 SUFFIX CODE MUST = 5
      *
      *    SUPPORT PRICE CROPS
      *    - Price Election should equal the Support Price.
      *
      *    ALL OTHER PLANS/CROPS
      *    IF ADM4 SUFFIX CODE = 5 (SUPPORT PRICE)
      *       PRICE ELECTION MUST = SUPPORT PRICE
      *
      *    IF ADM4 SUFFIX CODE = 1 (CAT & EST. HIGH PRICE)
      *       PRICE ELECTION MUST BE >= CAT PRICE AND
      *       PRICE ELECTION MUST BE <= ESTABLISHED HIGH PRICE
      *       IF CAT COVERAGE, PRICE ELECTION = CAT PRICE
      *
      *    IF ADM4 SUFFIX CODE = 2 (CAT, EST. HIGH & MARKET PRICE)
      *       PRICE ELECTION MUST BE >= CAT PRICE AND
      *       IF MARKET PRICE > ZERO
      *          PRICE ELECTION MUST BE <= MARKET PRICE
      *       ELSE
      *          PRICE ELECTION MUST BE <= ESTABLISHED HIGH PRICE
      *       IF CAT COVERAGE, PRICE ELECTION = CAT PRICE
      *
      *    IF ADM4 SUFFIX CODE = 6 (CAT, EST. HIGH & SEASON AVERAGE)
      *       PRICE ELECTION MUST BE >= CAT PRICE AND
      *       IF SEASON AVERAGE PRICE > ZERO
      *          PRICE ELECTION MUST BE <= SEASON AVERAGE PRICE
      *       ELSE
      *          PRICE ELECTION MUST BE <= ESTABLISHED HIGH PRICE
      *       IF CAT COVERAGE, PRICE ELECTION = CAT PRICE
      *****************************************************************

       2295-VAL-PRICE-ELECTION.

      $IF DEBUG-SW DEFINED
           DISPLAY '2295-VALIDATING PRICE ELECTION FOR TYPE 11'
           UPON CONSOLE
      $END

      *****************************************************************
      *       INITIALIZE LOCAL & OUTPUT VARIABLES                     *
      *****************************************************************
           INITIALIZE WS-2295-WORK
           INITIALIZE WS-2295-OUTPUT
           MOVE WS-LITERAL-NO TO WS-2295-UPDATE-PRICE-ELECTION

      *****************************************************************
      *       CHECK PRE-CONDITIONS                                    *
      *****************************************************************

           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-PRICE-ELECTION = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-RO = WS-LITERAL-YES OR
              ERROR-CVG-FL = WS-LITERAL-YES OR
              ERROR-RATE-CLASS = WS-LITERAL-YES OR
              ERROR-TYPE-PRACTICE-OPT-CD = WS-LITERAL-YES OR
              ERROR-CRUSH-DISTRICT = WS-LITERAL-YES OR
              ERROR-QUOTA = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
              GO TO 2295-VAL-PRICE-ELECTION-EXIT
           END-IF

           if ws-2295-crop-cd = ws-literal-potatoes and
               ws-2295-type-practice-option = 'CS'
               GO TO 2295-VAL-PRICE-ELECTION-EXIT
           end-if

      *****************************************************************
      *       SET UP DISPLAY FIELDS                                   *
      *****************************************************************
           MOVE WS-2295-PRICE-ELECTION TO WS-2295-PRICE-ELECTION-X

      $IF DEBUG-SW DEFINED
           DISPLAY 'PRICE ELECTION = ', WS-2295-PRICE-ELECTION-X
           UPON CONSOLE
      $END

      *    IF THE RECORD MATCHES ONE OF THE CONTRACT CROPS
      *    LISTED IN M13 20-4, EXIT PROCESSING. (THE PRICE
      *    ELECTION SHOULD MATCH THE CONTRACT PRICE FOR THE
      *    CROP. WE CANNOT VERIFY THIS; NO FURTHER PROCESSING
      *    IS NECESSARY.)

           IF (WS-2295-CROP-CD = WS-LITERAL-CANNING-BEANS AND
               WS-2295-RATE-STATE = WS-LITERAL-IDAHO AND
              (WS-2295-TYPE-CD = '301' OR WS-2295-TYPE-CD = '302')) OR
              (WS-2295-CROP-CD = WS-LITERAL-CANNING-BEANS AND
               WS-2295-RATE-STATE = WS-LITERAL-UTAH AND
               WS-2295-TYPE-CD = '301') OR
              (WS-2295-CROP-CD = WS-LITERAL-CANNING-BEANS AND
               WS-2295-RATE-STATE = WS-LITERAL-OREGON AND
               WS-2295-RATE-COUNTY = '045' AND
               WS-2295-TYPE-CD = '302') OR
              (WS-2295-CROP-CD = WS-LITERAL-DRY-BEANS AND
               WS-2295-TYPE-CD = '062') OR
              (WS-2295-CROP-CD = WS-LITERAL-GREEN-PEAS) OR
              (WS-2295-CROP-CD = WS-LITERAL-DRY-PEAS AND
               WS-2295-TYPE-CD = '098')

               IF CAT-COVERAGE
                  MOVE WS-2295-PRICE-ELECTION
                    TO WS-2295-CAT-100-PCT-PRICE
               END-IF
               GO TO 2295-VAL-PRICE-ELECTION-EXIT
           END-IF

      *****************************************************
      *            FLORIDA FRUIT TREES                    *
      *****************************************************
           IF WS-2295-INS-PLAN-CD = WS-LITERAL-FLORIDA-FRUIT
              PERFORM 2295-LOOKUP-REF-MAX-PRICE
                 THRU 2295-LOOKUP-REF-MAX-PRICE-EXIT

              IF ERROR-PRICE-ELECTION = WS-LITERAL-YES
                 GO TO 2295-VAL-PRICE-ELECTION-EXIT
              END-IF

              IF CAT-COVERAGE
      *          *** SAVE 100% PRICE AND SET UP 60% PRICE ELECTION
      *          *** FOR COMPARISON
                 MOVE WS-2295-REF-MAX-PRICE
                   TO WS-2295-CAT-100-PCT-PRICE
                 MOVE WS-2295-CALC-CAT-MAX-PRICE
                   TO WS-2295-REF-MAX-PRICE
              END-IF

              IF WS-2295-PRICE-ELECTION NOT = WS-2295-REF-MAX-PRICE
                 MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 015 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                 MOVE WS-LITERAL-PRICE-ELECT TO WS-8000-FIELD-NAME1
                 MOVE WS-2295-PRICE-ELECTION-X
                   TO WS-8000-BAD-DATA1
                 MOVE WS-LITERAL-INSURE-PLAN-CD TO WS-8000-FIELD-NAME2
                 MOVE SPACES TO WS-8000-BAD-DATA2
                 MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME3
                 MOVE SPACES TO WS-8000-BAD-DATA3
                 MOVE WS-2295-REF-MAX-PRICE TO WS-8000-CORR-DATA1
                 MOVE WS-2295-INS-PLAN-CD TO WS-8000-CORR-DATA2
                 MOVE WS-2295-CROP-CD TO WS-8000-CORR-DATA3
                 MOVE 2295 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF

              GO TO 2295-VAL-PRICE-ELECTION-EXIT
           END-IF

      *****************************************************
      *    MALT BARLEY - TYPE PRACTICE OPTIONS A AND B    *
      *****************************************************
           IF WS-2295-CROP-CD = WS-LITERAL-BARLEY
              EVALUATE WS-2295-TYPE-PRACTICE-OPTION
               WHEN WS-LITERAL-MALT-BARLEY-OPT-A
                  IF WS-2295-PRICE-ELECTION < .34 OR
                     WS-2295-PRICE-ELECTION > .50
                     MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 008 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-LITERAL-PRICE-ELECT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2295-PRICE-ELECTION-X
                       TO WS-8000-BAD-DATA1
                     MOVE '.34 - .50' TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
                  GO TO 2295-VAL-PRICE-ELECTION-EXIT
               WHEN WS-LITERAL-MALT-BARLEY-OPT-B
                  IF WS-2295-PRICE-ELECTION < 0.01 OR
                     WS-2295-PRICE-ELECTION > 2.00
                     MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 008 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-LITERAL-PRICE-ELECT
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2295-PRICE-ELECTION-X
                       TO WS-8000-BAD-DATA1
                     MOVE '.01 - 2.00' TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
                  GO TO 2295-VAL-PRICE-ELECTION-EXIT
               WHEN OTHER
                  CONTINUE
              END-EVALUATE
           END-IF

      *****************************************************
      *        GRP AND SPECIAL CROPS                      *
      *****************************************************
           IF WS-2295-INS-PLAN-CD = WS-LITERAL-GRP

              OR SPECIFIED-CROPS-2295
              OR (WS-2295-CROP-CD = WS-LITERAL-FRESH-TOMATOES
                 AND WS-2295-RATE-STATE = WS-LITERAL-FLORIDA
                 AND NOT SPECIFIED-FLORIDA-COUNTY-2295)

              IF WS-2295-INS-PLAN-CD = WS-LITERAL-DOLLAR-AMT
                    and ws-2295-price-election >= 1.0
                   GO TO 2295-VAL-PRICE-ELECTION-EXIT
              ELSE  
                   if ws-2295-price-election = 0
                       move 1 to ws-2295-price-election
                       GO TO 2295-VAL-PRICE-ELECTION-EXIT
                   end-if
              end-if

              IF WS-2295-PRICE-ELECTION = 1.0 OR
                 WS-2295-PRICE-ELECTION = ZERO
                 IF CAT-COVERAGE
                    MOVE .60 TO WS-2295-CAT-60-PCT-PRICE
                    MOVE 1.0 TO WS-2295-CAT-100-PCT-PRICE
                 END-IF
              ELSE
                 MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 008 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                 MOVE WS-LITERAL-PRICE-ELECT TO WS-8000-FIELD-NAME1
                 MOVE WS-2295-PRICE-ELECTION-X
                   TO WS-8000-BAD-DATA1
                 MOVE '1.0000' TO WS-8000-CORR-DATA1
                 MOVE 2295 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              GO TO 2295-VAL-PRICE-ELECTION-EXIT
           END-IF

      *****************************************************
      *    DOLLAR CROPS & AVOCADOS                        *
      *****************************************************
           IF WS-2295-INS-PLAN-CD = WS-LITERAL-DOLLAR-AMT OR
              WS-2295-INS-PLAN-CD = WS-LITERAL-ARC
              IF CAT-COVERAGE
                 MOVE .60 TO WS-2295-CAT-60-PCT-PRICE
                 MOVE 1.0 TO WS-2295-CAT-100-PCT-PRICE
              END-IF
              IF WS-2295-PRICE-ELECTION <> ZERO
                 MOVE WS-LITERAL-YES TO WS-2295-UPDATE-PRICE-ELECTION
                 MOVE ZERO TO WS-2295-NEW-PRICE-ELECTION
      *          MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
      *          MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
      *          MOVE 007 TO WS-8000-SHORT-ERROR
      *          MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
      *          MOVE WS-LITERAL-PRICE-ELECT TO WS-8000-FIELD-NAME1
      *          MOVE WS-2295-PRICE-ELECTION-X
      *            TO WS-8000-BAD-DATA1
      *          MOVE '0.0000' TO WS-8000-CORR-DATA1
      *          MOVE 2295 TO WS-8000-PARAGRAPH-NO
      *          PERFORM 8000-RECORD-TRAN-ERROR
      *             THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              GO TO 2295-VAL-PRICE-ELECTION-EXIT
           END-IF

      *****************************************************
      *   BYPASS ADM LOOKUP FOR TYPE21 RECORDS BECAUSE    *
      *   OF ERRORS CAUSED BY THE LACK OF RATE STATE/CNTY *
      *****************************************************
           IF TYPE21
              IF WS-2295-PRICE-ELECTION = ZERO
                 MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                 MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                 MOVE 005 TO WS-8000-SHORT-ERROR
                 MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                 MOVE WS-LITERAL-PRICE-ELECT
                   TO WS-8000-FIELD-NAME1
                 MOVE WS-2295-PRICE-ELECTION-X
                   TO WS-8000-BAD-DATA1
                 MOVE '> ZERO'
                   TO WS-8000-CORR-DATA1
                 MOVE 2295 TO WS-8000-PARAGRAPH-NO
                 PERFORM 8000-RECORD-TRAN-ERROR
                    THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-IF
              GO TO 2295-VAL-PRICE-ELECTION-EXIT
           END-IF

      *=========================================================*
      *    LOOKUP ADM4 RECORD TO DETERMINE SUBSEQUENT EDITS     *
      *=========================================================*
           PERFORM 2295-LOOKUP-PRICE-ELECT
              THRU 2295-LOOKUP-PRICE-ELECT-EXIT

           IF ERROR-PRICE-ELECTION = WS-LITERAL-YES
              GO TO 2295-VAL-PRICE-ELECTION-EXIT
           END-IF

      *****************************************************
      *          CHECK ADM RECORD AGAINST PLAN CODE       *
      *****************************************************
           EVALUATE WS-2295-INS-PLAN-CD
               WHEN WS-LITERAL-IP
                  IF WS-2295-ADM4-SUFFIX <> 7
                     MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-LITERAL-PRICE-ELECT
                       TO WS-8000-FIELD-NAME1
                     MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
                     STRING 'ADM4 SUFFIX FOUND = '
                       DELIMITED BY SIZE
                       WS-2295-ADM4-SUFFIX
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN WS-LITERAL-CRC
                  IF WS-2295-ADM4-SUFFIX <> 8
                     MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-LITERAL-PRICE-ELECT
                       TO WS-8000-FIELD-NAME1
                     MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
                     STRING 'ADM4 SUFFIX FOUND = '
                       DELIMITED BY SIZE
                       WS-2295-ADM4-SUFFIX
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN WS-LITERAL-RA
                  IF WS-2295-ADM4-SUFFIX <> 3
                     MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-LITERAL-PRICE-ELECT
                       TO WS-8000-FIELD-NAME1
                     MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
                     STRING 'ADM4 SUFFIX FOUND = '
                       DELIMITED BY SIZE
                       WS-2295-ADM4-SUFFIX
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN WS-LITERAL-PEANUTS-PLAN
                  IF WS-2295-ADM4-SUFFIX <> 4
                     MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-LITERAL-PRICE-ELECT
                       TO WS-8000-FIELD-NAME1
                     MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
                     STRING 'ADM4 SUFFIX FOUND = '
                       DELIMITED BY SIZE
                       WS-2295-ADM4-SUFFIX
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN WS-LITERAL-QUOTA-TOBACCO
                  IF WS-2295-ADM4-SUFFIX <> 5
                     MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-LITERAL-PRICE-ELECT
                       TO WS-8000-FIELD-NAME1
                     MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
                     STRING 'ADM4 SUFFIX FOUND = '
                       DELIMITED BY SIZE
                       WS-2295-ADM4-SUFFIX
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN OTHER
                  CONTINUE
           END-EVALUATE

           IF ERROR-PRICE-ELECTION = WS-LITERAL-YES
              GO TO 2295-VAL-PRICE-ELECTION-EXIT
           END-IF


      *****************************************************
      *        SET UP EDIT BASED ON SUFFIX CODE           *
      *****************************************************

           EVALUATE WS-2295-ADM4-SUFFIX
               WHEN 1
                  if cat-coverage and ws-2295-crop-cd =
                    ws-literal-forage-prod
                    move ws-2295-cat-price to ws-2295-test-cat-dollar
                    move ws-2295-cat-price to ws-2295-test-cat-cents
                    if ws-2295-test-cat-cents > .00
                       add 1 to ws-2295-test-cat-dollar
                    end-if
                  end-if
                  MOVE WS-2295-CAT-PRICE
                    TO WS-2295-MIN-PRICE
                  MOVE WS-2295-ESTABLISHED-HIGH-PRICE
                    TO WS-2295-MAX-PRICE
      *           *** SET UP CAT COVERAGE FIELDS
                  MOVE WS-2295-CAT-PRICE
                    TO WS-2295-CAT-60-PCT-PRICE
                  MOVE WS-2295-ESTABLISHED-HIGH-PRICE
                    TO WS-2295-CAT-100-PCT-PRICE

               WHEN 2
                  MOVE WS-2295-CAT-PRICE
                    TO WS-2295-MIN-PRICE
                  IF WS-2295-MARKET-PRICE > ZERO
                     MOVE WS-2295-MARKET-PRICE
                       TO WS-2295-MAX-PRICE
                  ELSE
                     MOVE WS-2295-ESTABLISHED-HIGH-PRICE
                       TO WS-2295-MAX-PRICE
                  END-IF
      *           *** SET UP CAT COVERAGE FIELDS
                  MOVE WS-2295-CAT-PRICE
                    TO WS-2295-CAT-60-PCT-PRICE
                  MOVE WS-2295-MAX-PRICE
                    TO WS-2295-CAT-100-PCT-PRICE

               WHEN 3
                  MOVE WS-2295-PROJ-HARVEST-PRICE
                    TO WS-2295-CORRECT-PRICE
      *           *** CAT COVERAGE NOT AVAILABLE

               WHEN 4
                  IF WS-2295-INS-PLAN-CD = WS-LITERAL-PEANUTS-PLAN
                     IF NOT-SET-0009
                        MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                        MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
                        MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                        MOVE 90003 TO WS-8000-ERROR-CODE
                        MOVE 2295 TO WS-8000-PARAGRAPH-NO
                        MOVE 'QUOTA FLAG' TO WS-8000-FIELD-NAME1
                        MOVE WS-0009-PEANUT-FLAG TO WS-8000-BAD-DATA1
                        MOVE 'Q OR N' TO WS-8000-CORR-DATA1
                        PERFORM 8000-RECORD-TRAN-ERROR
                           THRU 8000-RECORD-TRAN-ERROR-EXIT
                        GO TO 2295-VAL-PRICE-ELECTION-EXIT
                     ELSE
                        IF QUOTA-PEANUTS-0009
                           MOVE WS-2295-QUOTA-PRICE
                             TO WS-2295-MAX-PRICE
                        ELSE
                           MOVE WS-2295-NON-QUOTA-PRICE
                            TO WS-2295-MAX-PRICE
                        END-IF
                     END-IF

      *           *** SET UP CAT COVERAGE FIELDS
                  COMPUTE WS-2295-MIN-PRICE ROUNDED =
                     WS-2295-MAX-PRICE * 0.60
                     ON SIZE ERROR
                        MOVE 2295 TO WS-8020-PARAGRAPH-NO
                        MOVE 90017 TO WS-8020-INT-ERROR-NO
                        MOVE 'QUOTA PRICE * 60%'
                          TO WS-8020-FIELD-NAME
                        MOVE WS-LITERAL-YES
                          TO WS-8020-ABORT-PROGRAM
                        PERFORM 8020-RECORD-INT-ERROR
                           THRU 8020-RECORD-INT-ERROR-EXIT
                  END-COMPUTE
                  MOVE WS-2295-MIN-PRICE
                    TO WS-2295-CAT-60-PCT-PRICE
                  MOVE WS-2295-MAX-PRICE
                    TO WS-2295-CAT-100-PCT-PRICE

               WHEN 5
                  MOVE WS-2295-SUPPORT-PRICE
                    TO WS-2295-CORRECT-PRICE
      *           *** SET UP CAT COVERAGE FIELDS
                  COMPUTE WS-2295-CAT-60-PCT-PRICE ROUNDED =
                     WS-2295-SUPPORT-PRICE * 0.60
                     ON SIZE ERROR
                        MOVE 2295 TO WS-8020-PARAGRAPH-NO
                        MOVE 90017 TO WS-8020-INT-ERROR-NO
                        MOVE 'SUPPORT PRICE * 60%'
                          TO WS-8020-FIELD-NAME
                        MOVE WS-LITERAL-YES
                          TO WS-8020-ABORT-PROGRAM
                        PERFORM 8020-RECORD-INT-ERROR
                           THRU 8020-RECORD-INT-ERROR-EXIT
                  END-COMPUTE
                  MOVE WS-2295-SUPPORT-PRICE
                    TO WS-2295-CAT-100-PCT-PRICE

               WHEN 6
                  MOVE WS-2295-CAT-PRICE
                    TO WS-2295-MIN-PRICE
                  IF WS-2295-SEASON-AVERAGE-PRICE > ZERO
                     MOVE WS-2295-SEASON-AVERAGE-PRICE
                       TO WS-2295-MAX-PRICE
                  ELSE
                     MOVE WS-2295-ESTABLISHED-HIGH-PRICE
                       TO WS-2295-MAX-PRICE
                  END-IF
      *           *** SET UP CAT COVERAGE FIELDS
                  MOVE WS-2295-CAT-PRICE
                    TO WS-2295-CAT-60-PCT-PRICE
                  MOVE WS-2295-MAX-PRICE
                    TO WS-2295-CAT-100-PCT-PRICE

               WHEN 7
                  MOVE WS-2295-PRE-SALES-PRICE
                    TO WS-2295-CORRECT-PRICE
      *           *** CAT COVERAGE NOT AVAILABLE

               WHEN 8
                  MOVE WS-2295-SPRING-MARKET-PRICE
                    TO WS-2295-CORRECT-PRICE
      *           *** CAT COVERAGE NOT AVAILABLE
               WHEN 9
                  CONTINUE
           END-EVALUATE

      *****************************************************
      *        EDIT CAT COVERAGE PRICE ELECTION           *
      *****************************************************
           IF CAT-COVERAGE
              MOVE WS-2295-CAT-60-PCT-PRICE
                TO WS-2295-CORRECT-PRICE
              MOVE ZEROS TO WS-2295-MIN-PRICE
              MOVE ZEROS TO WS-2295-MAX-PRICE
           END-IF


      *****************************************************
      *            ALL OTHER CROPS/PLANS                  *
      *****************************************************

      *    *** SET UP VALID PRICE ELECTION DISPLAY FIELDS FOR ERRORS
           MOVE WS-2295-MIN-PRICE
             TO WS-2295-MIN-PRICE-X
           MOVE WS-2295-MAX-PRICE
             TO WS-2295-MAX-PRICE-X
           MOVE WS-2295-CORRECT-PRICE
             TO WS-2295-CORRECT-PRICE-X

      $IF DEBUG-SW DEFINED
           IF WS-2295-CORRECT-PRICE > ZERO
              DISPLAY 'CORRECT PRICE ELECTION = ',
              WS-2295-CORRECT-PRICE-X
              UPON CONSOLE
           ELSE
              DISPLAY 'MINIMUM PRICE ELECTION = ',
              WS-2295-MIN-PRICE-X
              UPON CONSOLE
              DISPLAY 'MAXIMUM PRICE ELECTION = ',
              WS-2295-MAX-PRICE-X
              UPON CONSOLE
           END-IF
      $END

      *    *** SEE IF THERE IS ONE CORRECT PRICE ***
           IF WS-2295-CORRECT-PRICE > ZERO
              IF WS-2295-PRICE-ELECTION <> WS-2295-CORRECT-PRICE
               if WS-2295-INS-PLAN-CD <> ws-literal-ra or
                WS-2295-PRICE-ELECTION <
                 (WS-2295-CORRECT-PRICE - .01) or
                WS-2295-PRICE-ELECTION >
                 (WS-2295-CORRECT-PRICE + .01)
                 move ws-2295-test-cat-dollar to WS-2295-CORRECT-PRICE
                 IF WS-2295-PRICE-ELECTION <> WS-2295-CORRECT-PRICE
                  if WS-2295-INS-PLAN-CD <> ws-literal-ra or
                   WS-2295-PRICE-ELECTION <
                    (WS-2295-CORRECT-PRICE - .01) or
                   WS-2295-PRICE-ELECTION >
                    (WS-2295-CORRECT-PRICE + .01)
                    MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 015 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                    MOVE WS-LITERAL-PRICE-ELECT
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2295-PRICE-ELECTION-X
                      TO WS-8000-BAD-DATA1
                    MOVE WS-2295-CORRECT-PRICE-X
                      TO WS-8000-CORR-DATA1
                    MOVE 2295 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                  end-if
                 end-if
               end-if
              END-IF
              GO TO 2295-VAL-PRICE-ELECTION-EXIT
           END-IF

      *    *** CORRECT PRICE IS A RANGE ***
           IF WS-2295-PRICE-ELECTION < WS-2295-MIN-PRICE
              OR WS-2295-PRICE-ELECTION > WS-2295-MAX-PRICE
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 015 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
              MOVE WS-LITERAL-PRICE-ELECT
                TO WS-8000-FIELD-NAME1
              MOVE WS-2295-PRICE-ELECTION-X
                TO WS-8000-BAD-DATA1
              STRING 'RANGE = '
                  DELIMITED BY SIZE
                  WS-2295-MIN-PRICE-X
                  DELIMITED BY SIZE
                  ' - '
                  DELIMITED BY SIZE
                  WS-2295-MAX-PRICE-X
                  DELIMITED BY SIZE
                  INTO WS-8000-CORR-DATA1
              END-STRING
              MOVE 2295 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.


       2295-VAL-PRICE-ELECTION-EXIT.
           EXIT.


      $IF ISAM-SW DEFINED

       2295-LOOKUP-PRICE-ELECT.

      *****************************************************************
      *       LOOKUP PRICE ELECTION IN ADM4                           *
      *****************************************************************
           INITIALIZE WS-7520-INPUT-KEY
           MOVE WS-2295-CROP-CD TO WS-7520-INPUT-CROP-CD
           MOVE WS-2295-INS-PLAN-CD TO WS-7520-INPUT-INSURANCE-PLAN
           MOVE WS-2295-RATE-STATE TO WS-7520-INPUT-STATE-CD
           MOVE WS-2295-RATE-COUNTY TO WS-7520-INPUT-COUNTY-CD
           MOVE WS-2295-TYPE-CD TO WS-7520-INPUT-TYPE-CD
           MOVE WS-2295-PRACTICE-CD TO WS-7520-INPUT-PRACTICE-CD
           MOVE WS-2295-CROP-YR TO WS-7520-INPUT-CROP-YR

      **************************************************
      *    DETERMINE WHICH INDEX VALUE TO USE          *
      **************************************************

           EVALUATE WS-2295-CROP-CD
               WHEN WS-LITERAL-GRAPES
                  MOVE WS-2295-CRUSH-DISTRICT
                    TO WS-2295-CRUSH-DISTRICT-2
                  MOVE WS-2295-CRUSH-DISTRICT-3
                    TO WS-7520-INPUT-INDEX
               WHEN OTHER
                  MOVE ZEROS TO WS-7520-INPUT-INDEX
           END-EVALUATE

      *    *** SET UP ERROR STRING IN CASE ADM4 NOT FOUND
           STRING 'ADM4 KEY = '
               DELIMITED BY SIZE
               WS-7520-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           PERFORM 7520-LOOKUP-ADM4
              THRU 7520-LOOKUP-ADM4-EXIT

           IF NOT MATCH-FOUND-7520
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
              MOVE WS-LITERAL-PRICE-ELECT TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 2295 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2295-LOOKUP-PRICE-ELECT-EXIT
           END-IF

      *****************************************************
      *    MATCH FOUND - MOVE DATA TO LOCAL FIELDS        *
      *****************************************************
           MOVE WS-7520-ADM4-DATA
             TO WS-2295-ADM4-DATA

      *    *** CLEAR THE ERROR SET ABOVE
           MOVE SPACES TO WS-8000-CORR-DATA1

      *****************************************************
      *    CHECK FIELDS TO MAKE SURE DATA IS GOOD         *
      *****************************************************
           EVALUATE WS-2295-ADM4-SUFFIX
               WHEN 1
                  IF WS-2295-CAT-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 CAT PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
                  IF WS-2295-ESTABLISHED-HIGH-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 EST HIGH PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN 2
                  IF WS-2295-CAT-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 CAT PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
                  IF WS-2295-ESTABLISHED-HIGH-PRICE = ZEROS AND
                     WS-2295-MARKET-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 HIGH & MKT'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN 3
                  IF WS-2295-PROJ-HARVEST-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 PROJ HVST PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN 4
                  IF WS-2295-QUOTA-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 QUOTA PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN 5
                  IF WS-2295-SUPPORT-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 SUPPORT PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN 6
                  IF WS-2295-CAT-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 CAT PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
                  IF WS-2295-ESTABLISHED-HIGH-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 EST HIGH PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
                  IF WS-2295-SEASON-AVERAGE-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 SEASON AVG PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN 7
                  IF WS-2295-PRE-SALES-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 PRE-SALES PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN 8
                  IF WS-2295-SPRING-MARKET-PRICE = ZEROS
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 SPRING MKT PRICE'
                       TO WS-8000-FIELD-NAME1
                     MOVE ZEROS TO WS-8000-BAD-DATA1
                     MOVE '> ZERO'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
               WHEN 9
                  IF WS-2295-CONTRACT-PRICE-CODE <> 'CP'
                     MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                     MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                     MOVE 009 TO WS-8000-SHORT-ERROR
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 'ADM4 CONTRACT PRICE CD'
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2295-CONTRACT-PRICE-CODE
                       TO WS-8000-BAD-DATA1
                     MOVE 'CP'
                       TO WS-8000-CORR-DATA1
                     MOVE 2295 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                   else
               IF CAT-COVERAGE
                  MOVE WS-2295-PRICE-ELECTION
                    TO WS-2295-CAT-100-PCT-PRICE
               END-IF

                  END-IF
               WHEN OTHER
                  MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
                  MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                  MOVE 044 TO WS-8000-SHORT-ERROR
                  MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                  MOVE 'ADM4 SUFFIX'
                    TO WS-8000-FIELD-NAME1
                  MOVE WS-2295-ADM4-SUFFIX TO WS-8000-BAD-DATA1
                  MOVE 'NO LOGIC FOR THIS PRICE SUFFIX'
                    TO WS-8000-CORR-DATA1
                  MOVE 2295 TO WS-8000-PARAGRAPH-NO
                  PERFORM 8000-RECORD-TRAN-ERROR
                     THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-EVALUATE.



       2295-LOOKUP-PRICE-ELECT-EXIT.
           EXIT.

       2295-LOOKUP-REF-MAX-PRICE.

      $IF ISAM-SW DEFINED

      *****************************************************************
      *       LOOKUP REF MAX PRICE IN ADM1                            *
      *****************************************************************
           INITIALIZE WS-7505-INPUT-KEY
           MOVE WS-2295-CROP-YR TO WS-7505-INPUT-CROP-YR
           MOVE WS-2295-RATE-STATE TO WS-7505-INPUT-STATE-CD
           MOVE WS-2295-RATE-COUNTY TO WS-7505-INPUT-COUNTY-CD
           MOVE WS-2295-CROP-CD TO WS-7505-INPUT-CROP-CD
           MOVE WS-2295-INS-PLAN-CD TO ws-7505-input-insurance-plan
           MOVE WS-2295-PRACTICE-CD TO WS-7505-INPUT-PRACTICE-CD
           MOVE WS-2295-TYPE-CD TO WS-7505-INPUT-TYPE-CD
           MOVE WS-2295-RATE-CLASS TO WS-7505-INPUT-RATE-CLASS

           PERFORM 7505-LOOKUP-ADM1
              THRU 7505-LOOKUP-ADM1-EXIT

      *    *** SET UP ERROR STRING IN CASE ADM1 NOT FOUND
           STRING 'ADM1 KEY = '
               DELIMITED BY SIZE
               WS-7505-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING

           IF MATCH-FOUND-7505
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1
              IF WS-7505-REF-MAX-PRICE = ZEROS
                 MOVE 2295 TO WS-8020-PARAGRAPH-NO
                 MOVE 9049 TO WS-8020-INT-ERROR-NO
                 MOVE 'WS-7520-PRICE-02' TO WS-8020-FIELD-NAME
                 MOVE '00000.00' TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
              ELSE
                 MOVE WS-7505-REF-MAX-PRICE
                   TO WS-2295-REF-MAX-PRICE
              END-IF

      *****************************************************************
      *  WHEN THE ADM LOOKUP IS USED, PROCESSING FOR CAT TYPE         *
      *  11S REQUIRES THAT THE ADM REF MAX PRICE FIELD MUST BE        *
      *  ADJUSTED TO REFLECT THE CAT PRICE ELECTION.                  *
      *****************************************************************

              IF CAT-COVERAGE
                   move WS-7505-CAT-DOLLAR-AMT-INS
                        to ws-2295-calc-cat-max-price
                   move WS-2295-CALC-CAT-MAX-PRICE
                        to ws-2295-cat-60-pct-price
              END-IF
           ELSE
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 009 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-PRICE-ELECTION
              MOVE WS-LITERAL-PRICE-ELECT TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 2295 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.
      $END


       2295-LOOKUP-REF-MAX-PRICE-EXIT.
           EXIT.


      $END
