      *****************************************************************
      * File:      IF2320.CBL
      * Author:    Laura Dittamo
      * Date:      10/12/95
      * Purpose:
      *    This routine performs three tasks. It validates the Date
      *    Planted, identifies the Seed Cycle Code, and determines the
      *    correct guarantee reduction percent for the input
      *    Type 11 if late planting applies.
      *
      *
      *    Late Planting (Guarantee Reduction Flag = 'L')
      *
      *    Crop List 01:
      *    May be planted up to 25 days after the final planting date.
      *    Days Late  LPO Reduction
      *    01-10      1% per day
      *    11-25      2% per day
      *    Example:  23 days late = 10 x 1% + 13 x 2% = 36% reduction
      *
      *    Crop List 02:
      *    May be planted up to 20 days after the final planting date.
      *    Days Late  LPO Reduction
      *    01-05      10%
      *    06-10      20%
      *    11-15      30%
      *    16-20      40%
      *    Example:  18 days late = 40% = 40% reduction
      *
      *    Millet:
      *    May be planted up to 20 days after the final planting date.
      *    Days Late  LPO Reduction
      *    01-10      1% per day
      *    11-20      3% per day
      *    Example:  18 days late = 10 x 1% + 8 x 3% = 34% reduction
      *
      *    Canola for Minnesota and North Dakota only:
      *    May be planted up to 15 days after the final planting date.
      *    Days Late  LPO Reduction
      *    01-05      2% per day
      *    06-15      3% per day
      *    Example:  12 days late = 05 x 2% + 7 x 3% = 31% reduction
      *
      *
      *    Prevented Planting (Guarantee Reduction Flag = 'P')
      *
      *    If the date planted is not zeros, it must be at least one day
      *    after the final planting date for Fall Wheat and at least 26
      *    days after the final planting date for all other crops.
      *
      *    Normal Planting (Guarantee Reduction Flag = ' ')
      *
      *    Crop must be planted before the extended final planting date.
      *
      * -- Determination of Seed Cycle Code.  The Seed Cycle Code is set
      *    to either 'S' (Spring) or 'F' (Fall).  The Final Planting
      *    Date for the crop is evaluated to determine the Seed Cycle
      *    Code.  When the Final Planting Date is before 2/26 the Seed
      *    Cycle Code is set to 'F'.  If the Final Planted Date is after
      *    2/26 the Seed Cycle is 'S'.
      *****************************************************************

       2320-VAL-DATE-PLANTED.

      $IF DEBUG-SW DEFINED
           DISPLAY '2320-VALIDATING DATE PLANTED'
           UPON CONSOLE
      $END

      *********************************************************
      *       INITIALIZE LOCAL & OUTPUT VARIABLES
      *********************************************************
           INITIALIZE WS-2320-WORK
           INITIALIZE WS-2320-OUTPUT

      *********************************************************
      *       CHECK PRECONDITIONS
      *********************************************************

           IF ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-DT-PLANTED = WS-LITERAL-YES OR
              ERROR-RATE-COUNTY = WS-LITERAL-YES OR
              ERROR-RATE-STATE = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-PRACTICE-CD = WS-LITERAL-YES OR
              ERROR-GUAR-RED-FLG = WS-LITERAL-YES OR
              ERROR-GUAR-RED-PCT = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
              GO TO 2320-VAL-DATE-PLANTED-EXIT
           END-IF

      *********************************************************
      *    DATE PLANTED VALIDATION IS NOT APPLICABLE FOR:     *
      *                                                       *
      *    -TREE CROPS                                        *
      *    -PERENNIALS                                        *
      *    -GRP CROPS                                         *
      *    -FORAGE PRODUCTION                                 *
      *    -NURSERY                                           *
      *********************************************************

           MOVE WS-2320-CROP-CD TO WS-0009-CROP-CATEGORIES
           IF (WS-2320-INS-PLAN-ID = WS-LITERAL-GRP) OR
              (WS-2320-CROP-CD = WS-LITERAL-NURSERY) OR
              (WS-2320-CROP-CD = WS-LITERAL-FORAGE-PROD) OR
              PERENNIAL-CROP-0009 OR
              TREE-CROP-0009 OR
              CATEGORY-C-CROP-0009
      *       *** PERENNIAL CROPS ARE MOSTLY SPRING CROPS
      *       *** SO WE ARE SETTING THE SEED CYCLE CODE TO
      *       *** SPRING UNTIL WE HEAR OTHERWISE.
              MOVE WS-LITERAL-SPRING TO WS-2320-SEED-CYCLE-CD

      $IF DEBUG-SW DEFINED
           DISPLAY 'SKIPPING DATE PLANTED VALIDATION FOR CROP'
           UPON CONSOLE
           DISPLAY 'CROP IS ', WS-2320-CROP-CD
           UPON CONSOLE
      $END
              GO TO 2320-VAL-DATE-PLANTED-EXIT
           END-IF

      *********************************************************
      *    SOME COUNTIES IN TEXAS FOR COTTON AND IN WASHIGNTON*
      *    FOR WHEAT HAVE TWO FINAL PLANTING DATES. FOLLOWING *
      *    LOGIC IS INTENDED TO OBTAIN CORRECT FINAL PLANTING *
      *    DATE.                                              *
      *********************************************************

           MOVE WS-LITERAL-NO TO WS-7240-TXWA-EXDATE-FOUND-FLAG
           MOVE WS-LITERAL-NO TO WS-7240-TXWA-EXDATE-2PASS-FLAG

           PERFORM 2320-MAINVAL-DATE-PLANTED
              THRU 2320-MAINVAL-DATE-PLANTED-EXIT

           IF WS-7240-TXWA-EXDATE-FOUND-FLAG = WS-LITERAL-YES
              IF WS-2320-LPO-REDUCTION-PCT > ZEROS
                 IF (1.00 - WS-2320-LPO-REDUCTION-PCT) =
                                                WS-T11-GUARANTEE-RED-PCT
                    GO TO 2320-VAL-DATE-PLANTED-EXIT
                 END-IF
              ELSE
                 IF WS-2320-LPO-REDUCTION-PCT = WS-T11-GUARANTEE-RED-PCT
                   GO TO 2320-VAL-DATE-PLANTED-EXIT
                 END-IF
              END-IF

      *       *** Try again for the other final planting date...
              MOVE WS-LITERAL-YES TO WS-7240-TXWA-EXDATE-2PASS-FLAG
              PERFORM 2320-MAINVAL-DATE-PLANTED
                 THRU 2320-MAINVAL-DATE-PLANTED-EXIT
           END-IF.

       2320-VAL-DATE-PLANTED-EXIT.
           EXIT.


       2320-MAINVAL-DATE-PLANTED.
      *********************************************************
      *       LOOKUP DATES
      *********************************************************
           PERFORM 2320-LOOKUP-DATES
              THRU 2320-LOOKUP-DATES-EXIT
           IF ERROR-DT-PLANTED = WS-LITERAL-YES
              GO TO 2320-MAINVAL-DATE-PLANTED-EXIT
           END-IF

           IF WS-2320-FINAL-PLANTING-DATE = '00000000'
              MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
              MOVE 2320 TO WS-8000-PARAGRAPH-NO
              MOVE 11005 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE '7515-EXT-FINAL-PLANTING'
                   TO WS-8000-FIELD-NAME1
              MOVE '= zero' TO WS-8000-BAD-DATA1
              move 'valid planting date' to ws-8000-CORR-DATA1
              MOVE 'ADM3' TO WS-8000-TABLE-NAME
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2320-MAINVAL-DATE-PLANTED-EXIT
           END-IF

      ****************************************************************
      * FIND THE CORRESPONDING JULIAN DATE (YYYYDDD) FOR THE
      * FINAL PLANTING DATE
      ****************************************************************

           MOVE WS-2320-FINAL-PLANTING-DATE TO WS-0550-INPUT-DATE
           PERFORM 0550-GET-JULIAN-DATE
              THRU 0550-GET-JULIAN-DATE-EXIT
           MOVE WS-0550-OUTPUT-JULIAN-DATE
             TO WS-2320-JUL-FINAL-PLANTING-DT

      *********************************************************
      *       DETERMINE THE SEED CYCLE CODE
      *********************************************************

      * COMPARE THE FINAL PLANTING DATE WITH THE SPRING/FALL SEED
      * CYCLE CUTOFF DATE.  IF THE FINAL PLANTING DATE IS
      * BEFORE THE CUTOFF DATE THE CROP FOR THIS TYPE 11 HAS A FALL
      * SEED CYCLE.  OTHERWISE THE SEED CYCLE IS SPRING.
           MOVE 19970226 TO WS-2320-SEED-CYCLE-CUTOFF-DATE
           MOVE WS-2320-SEED-CYCLE-CUTOFF-DATE TO WS-0560-INPUT-DATE1
           MOVE WS-2320-FINAL-PLANTING-DATE TO WS-0560-INPUT-DATE2
           PERFORM 0560-COMPARE-DATES-6
              THRU 0560-COMPARE-DATES-6-EXIT

      *    *** DATE COMPARE FAILED
           IF NOT VALID-RESULT-FLAG-0560
              MOVE 2320 TO WS-8020-PARAGRAPH-NO
              MOVE 90004 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0560-RESULT-FLAG' TO WS-8020-FIELD-NAME
              MOVE WS-0560-RESULT-FLAG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF DATE1-GREATER-THAN-DATE2-0560
              MOVE WS-LITERAL-FALL TO WS-2320-SEED-CYCLE-CD
           ELSE
              MOVE WS-LITERAL-SPRING TO WS-2320-SEED-CYCLE-CD
           END-IF


      ****************************************************************
      *     MAKE SURE THAT THE CROP WAS PLANTED
      ****************************************************************
           IF WS-2320-INPUT-DATE-PLANTED = ZEROS
              IF WS-2320-GUARANTEE-RED-FLG = WS-LITERAL-PP
      *          *** NO FURTHER EDITS APPLY
                 GO TO 2320-MAINVAL-DATE-PLANTED-EXIT
              END-IF
              IF WS-2320-CROP-CD = WS-LITERAL-SUGAR-CANE
      *          *** NO GUARANTEE REDUCTION IS APPLICABLE
                 IF WS-2320-GUARANTEE-RED-FLG <> SPACES
                    MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                    MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
                    MOVE 040 TO WS-8000-SHORT-ERROR
                    MOVE WS-LITERAL-YES TO ERROR-GUAR-RED-FLG
                    MOVE WS-LITERAL-GUAR-RED-FLG TO WS-8000-FIELD-NAME1
                    MOVE WS-2380-GUARANTEE-RED-FLG TO WS-8000-BAD-DATA1
                    MOVE 2380 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
                 END-IF
      *          *** NO FURTHER EDITS APPLY
                 GO TO 2320-MAINVAL-DATE-PLANTED-EXIT
              END-IF
      *       *** NO SPECIAL CASES APPLY - DATE PLANTED SHOULD BE > ZEROS
              MOVE 11074 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
              MOVE WS-LITERAL-DT-PLANTED TO WS-8000-FIELD-NAME1
              MOVE '000000' TO WS-8000-BAD-DATA1
              MOVE '> ZEROS' TO WS-8000-CORR-DATA1
              MOVE 2320 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT

      *       *** NO FURTHER EDITS APPLY
              GO TO 2320-MAINVAL-DATE-PLANTED-EXIT
           END-IF

      *    *** CHECK FOR VALID YEAR PLANTED.
           IF ((WS-2320-IN-DATE-PLANTED-YY < (WS-2320-CROP-YEAR - 1))
           AND  WS-2320-CROP-CD <> WS-LITERAL-SUGAR-CANE)
           OR ((WS-2320-IN-DATE-PLANTED-YY < (WS-2320-CROP-YEAR - 3))
           AND  WS-2320-CROP-CD =  WS-LITERAL-SUGAR-CANE)
              MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
              MOVE WS-TRAN-TYPE   TO WS-8000-ERROR-TRAN-TYPE
              MOVE 017            TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
              MOVE 'PLANTED YR'   TO WS-8000-FIELD-NAME1
              MOVE WS-2320-IN-DATE-PLANTED-YY TO WS-8000-BAD-DATA1
              MOVE 'VALID DATE PLANTED YEAR'  TO WS-8000-CORR-DATA1
              MOVE 2320           TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
                GO TO 2320-MAINVAL-DATE-PLANTED-EXIT
           END-IF

      ****************************************************************
      * FIND THE CORRESPONDING JULIAN DATE (YYYYDDD) FOR THE
      * DATE PLANTED (IT IS GREATER THAN ZERO)
      ****************************************************************
              MOVE WS-2320-IN-DATE-PLANTED-YY TO WS-2320-DATE-PLANTED-YY
              MOVE WS-2320-IN-DATE-PLANTED-MM TO WS-2320-DATE-PLANTED-MM
              MOVE WS-2320-IN-DATE-PLANTED-DD TO WS-2320-DATE-PLANTED-DD
              MOVE WS-2320-LOCAL-DATE-PLANTED TO WS-0550-INPUT-DATE
      *       *** CONVERT DATE PLANTED TO JULIAN DATE
              PERFORM 0550-GET-JULIAN-DATE
                 THRU 0550-GET-JULIAN-DATE-EXIT
              MOVE WS-0550-OUTPUT-JULIAN-DATE
                TO WS-2320-JUL-DATE-PLANTED


      *****************************************************************
      *  DETERMINE NUMBER OF DAYS LATE.
      *  THIS CODE ASSUMES THAT THE FINAL PLANTING DATE WILL NEVER BE
      *  MORE THAN ONE CALENDAR YEAR PAST THE ACTUAL DATE PLANTED
      *****************************************************************

           COMPUTE WS-2320-DAYS-LATE =
              WS-2320-JUL-DATE-PLANTED
              - WS-2320-JUL-FINAL-PLANTING-DT9
           END-COMPUTE

           EVALUATE WS-2320-DAYS-LATE
               WHEN < 0
                  MOVE ZEROS TO WS-2320-DAYS-LATE
               WHEN > 366
      *           *** OFF BY MORE THAN 1 YEAR (SUBTRACT A YEAR & TRY AGAIN)
                 MOVE WS-2320-JUL-FINAL-PLANT-YR TO WS-0525-INPUT-YEAR
                 PERFORM 0525-DETERMINE-IF-LEAP-YR
                    THRU 0525-DETERMINE-IF-LEAP-YR-EXIT
                 IF LEAP-YEAR-0525
                     MOVE 366 TO WS-2320-DAYS-IN-YEAR
                 ELSE
                     MOVE 365 TO WS-2320-DAYS-IN-YEAR
                 END-IF
                 COMPUTE WS-2320-DAYS-LATE =
                     WS-2320-DAYS-LATE - (1000 - WS-2320-DAYS-IN-YEAR)
                 END-COMPUTE

               WHEN OTHER
                  CONTINUE
           END-EVALUATE

      *****************************************************************
      *  SEE IF LATE OR PREVENTED PLANTING FLAGS MAKE SENSE AND ARE
      *  VALID BASED UPO THE NUMBER OF DAYS LATE; IF LATE PLANTING
      *  APPLIES, COMPUTE THE LPO REDUCTION PERCENTAGE.
      *****************************************************************

           EVALUATE WS-2320-GUARANTEE-RED-FLG
               WHEN WS-LITERAL-PP
                  IF WS-2320-CROP-CD = WS-LITERAL-WHEAT AND
                     WS-2320-SEED-CYCLE-CD = WS-LITERAL-FALL
                     MOVE 01 TO WS-2320-VALID-PP-THRESHOLD
                  ELSE
                     MOVE 26 TO WS-2320-VALID-PP-THRESHOLD
                  END-IF

                  IF WS-2320-DAYS-LATE < WS-2320-VALID-PP-THRESHOLD

                     IF  WS-7240-TXWA-EXDATE-FOUND-FLAG = WS-LITERAL-YES
                     AND WS-7240-TXWA-EXDATE-2PASS-FLAG = WS-LITERAL-NO
                         GO TO 2320-MAINVAL-DATE-PLANTED-EXIT
                     END-IF

                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11057 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
                     MOVE WS-LITERAL-YES
                       TO ERROR-GUAR-RED-FLG
                     MOVE WS-LITERAL-YES
                       TO ERROR-GUAR-RED-PCT
                     MOVE WS-LITERAL-DT-PLANTED
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2320-INPUT-DATE-PLANTED
                       TO WS-8000-BAD-DATA1
                     STRING 'LATE DT = '
                        DELIMITED BY SIZE
                        WS-2320-DIS-FINAL-PLANT-DATE
                        DELIMITED BY SIZE
                        ', MUST BE >= '
                        DELIMITED BY SIZE
                        WS-2320-VALID-PP-THRESHOLD
                        DELIMITED BY SIZE
                        ' DAYS LATE'
                        DELIMITED BY SIZE
                        INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2320 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF

               WHEN WS-LITERAL-LPO
                  IF WS-2320-DAYS-LATE = ZERO

                     IF  WS-7240-TXWA-EXDATE-FOUND-FLAG = WS-LITERAL-YES
                     AND WS-7240-TXWA-EXDATE-2PASS-FLAG = WS-LITERAL-NO
                         GO TO 2320-MAINVAL-DATE-PLANTED-EXIT
                     END-IF

                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11057 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
                     MOVE WS-LITERAL-YES
                       TO ERROR-GUAR-RED-FLG
                     MOVE WS-LITERAL-YES
                       TO ERROR-GUAR-RED-PCT
                     MOVE WS-LITERAL-DT-PLANTED
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2320-INPUT-DATE-PLANTED
                       TO WS-8000-BAD-DATA1
                     STRING 'LATE DT = '
                        DELIMITED BY SIZE
                        WS-2320-DIS-FINAL-PLANT-DATE
                        DELIMITED BY SIZE
                        ', MUST BE > 0 DAYS LATE'
                        DELIMITED BY SIZE
                        INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2320 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  ELSE
                     PERFORM 2320-COMPUTE-LPO-PCT
                        THRU 2320-COMPUTE-LPO-PCT-EXIT
                     MOVE WS-2320-LPO-REDUCTION-PCT
                       TO WS-2320-LPO-REDUCTION-PCT-X
      $IF DEBUG-SW DEFINED
           DISPLAY 'LPO REDUCTION % = ', WS-2320-LPO-REDUCTION-PCT-X
           UPON CONSOLE
      $END
                  END-IF

               WHEN SPACES
                  IF WS-2320-DAYS-LATE > ZERO
                     MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
                     MOVE 11054 TO WS-8000-ERROR-CODE
                     MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
                     MOVE WS-LITERAL-YES
                       TO ERROR-GUAR-RED-FLG
                     MOVE WS-LITERAL-YES
                       TO ERROR-GUAR-RED-PCT
                     MOVE WS-LITERAL-GUAR-RED-FLG
                       TO WS-8000-FIELD-NAME1
                     MOVE WS-2320-GUARANTEE-RED-FLG
                       TO WS-8000-BAD-DATA1
                     STRING WS-2320-GUARANTEE-RED-FLG
                        DELIMITED BY SIZE
                        ', WHEN DAYS LATE > ZERO'
                        DELIMITED BY SIZE
                        INTO WS-8000-CORR-DATA1
                     END-STRING
                     MOVE 2320 TO WS-8000-PARAGRAPH-NO
                     PERFORM 8000-RECORD-TRAN-ERROR
                        THRU 8000-RECORD-TRAN-ERROR-EXIT
                  END-IF
           END-EVALUATE.


       2320-MAINVAL-DATE-PLANTED-EXIT.
           EXIT.


      $IF ISAM-SW DEFINED

       2320-LOOKUP-DATES.

      *    *** lookup Final Date in table for TX cotton/WA wheat
           IF (WS-2320-RATE-STATE = WS-LITERAL-TEXAS      AND
               WS-2320-CROP-CD    = WS-LITERAL-COTTON      OR
               WS-2320-RATE-STATE = WS-LITERAL-WASHINGTON AND
               WS-2320-CROP-CD    = WS-LITERAL-WHEAT)     AND
              (WS-7240-TXWA-EXDATE-FOUND-FLAG = WS-LITERAL-NO)
              MOVE WS-2320-RATE-STATE     TO WS-7240-TXWA-EXDATE-STATE
              MOVE WS-2320-RATE-COUNTY    TO WS-7240-TXWA-EXDATE-CNTY
              MOVE WS-2320-CROP-CD        TO WS-7240-TXWA-EXDATE-CROP
              IF WS-2320-CROP-CD = WS-LITERAL-COTTON
                 MOVE SPACES              TO WS-7240-TXWA-EXDATE-TYPE
                 MOVE SPACES              TO WS-7240-TXWA-EXDATE-PRAC
              ELSE
                 MOVE WS-2320-TYPE-CD     TO WS-7240-TXWA-EXDATE-TYPE
                 MOVE WS-2320-PRACTICE-CD TO WS-7240-TXWA-EXDATE-PRAC
              END-IF
              SET EXDATE TO 1
              SEARCH WS-7240-FINAL-DATE-TABLES
                 WHEN WS-7240-FINAL-DATE-KEY (EXDATE) =
                      WS-7240-TXWA-EXDATE-KEY
                    MOVE WS-7240-FINAL-DATE-MM (EXDATE)
                      TO WS-7240-TXWA-EXDATE-MM
                    MOVE WS-7240-FINAL-DATE-DD (EXDATE)
                      TO WS-7240-TXWA-EXDATE-DD
                    MOVE WS-2320-CROP-YEAR
                      TO WS-7240-TXWA-EXDATE-YY
                    MOVE WS-LITERAL-YES
                      TO WS-7240-TXWA-EXDATE-FOUND-FLAG
              END-SEARCH
           END-IF

      *    *** lookup dates in ADM3 record...
           INITIALIZE WS-7515-INPUT-KEY
           MOVE WS-2320-CROP-YEAR TO WS-7515-INPUT-CROP-YR
           MOVE WS-2320-RATE-STATE TO WS-7515-INPUT-STATE-CD
           MOVE WS-2320-RATE-COUNTY TO WS-7515-INPUT-COUNTY-CD
           MOVE WS-2320-CROP-CD TO WS-7515-INPUT-CROP-CD
           MOVE WS-2320-INS-PLAN-ID TO WS-7515-INPUT-INSURANCE-PLAN
           MOVE WS-2320-PRACTICE-CD TO WS-7515-INPUT-PRACTICE-CD
           MOVE WS-2320-TYPE-CD TO WS-7515-INPUT-TYPE-CD
           STRING 'ADM3 KEY = '
               DELIMITED BY SIZE
               WS-7515-INPUT-KEY
               DELIMITED BY SIZE
               INTO WS-8000-CORR-DATA1
           END-STRING
           PERFORM 7515-LOOKUP-ADM3
              THRU 7515-LOOKUP-ADM3-EXIT

           IF MATCH-FOUND-7515
      *       *** CLEAR THE ERROR SET ABOVE
              MOVE SPACES TO WS-8000-CORR-DATA1

              IF WS-7240-TXWA-EXDATE-FOUND-FLAG = WS-LITERAL-YES
                 IF WS-7240-TXWA-EXDATE-2PASS-FLAG = WS-LITERAL-NO
                    IF WS-7240-TXWA-EXDATE >
                            WS-7515-EXT-FINAL-PLANTING
                       MOVE WS-7240-TXWA-EXDATE
                         TO WS-2320-FINAL-PLANTING-DATE
                    ELSE
                       MOVE WS-7515-EXT-FINAL-PLANTING
                         TO WS-2320-FINAL-PLANTING-DATE
                    END-IF
                 ELSE
                    IF WS-7240-TXWA-EXDATE <
                            WS-7515-EXT-FINAL-PLANTING
                       MOVE WS-7240-TXWA-EXDATE
                         TO WS-2320-FINAL-PLANTING-DATE
                    ELSE
                       MOVE WS-7515-EXT-FINAL-PLANTING
                         TO WS-2320-FINAL-PLANTING-DATE
                    END-IF
                 END-IF
              ELSE
                 MOVE WS-7515-EXT-FINAL-PLANTING
                   TO WS-2320-FINAL-PLANTING-DATE
              END-IF

      **      SET UP ERROR DISPLAY FIELD FOR FINAL PLANTING DATE
              MOVE WS-2320-FINAL-PLANT-DT-YY TO WS-2320-DISPLAY-FPD-YY
              MOVE WS-2320-FINAL-PLANT-DT-MM TO WS-2320-DISPLAY-FPD-MM
              MOVE WS-2320-FINAL-PLANT-DT-DD TO WS-2320-DISPLAY-FPD-DD
           ELSE
      **      NO FINAL PLANTING DATE FOUND
              MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
              MOVE 2320 TO WS-8000-PARAGRAPH-NO
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE 'ADM3 REC' TO WS-8000-FIELD-NAME1
              MOVE 'NOT FOUND' TO WS-8000-BAD-DATA1
      *       *** SEARCH KEY USED IS IN CORR-DATA1
              MOVE 'ADM3' TO WS-8000-TABLE-NAME
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.
      $END

       2320-LOOKUP-DATES-EXIT.
           EXIT.


      *========================================================*
      *      COMPUTE LATE PLANTING PERCENTAGE                  *
      *========================================================*

       2320-COMPUTE-LPO-PCT.

      ****************************************************************
      * DETERMINE CORRECT LATE PLANTING REDUCTION - MILLET
      ****************************************************************
      *          20 DAY LATE PLANTING FOR MILLET

           IF WS-2320-CROP-CD = WS-LITERAL-MILLET
              EVALUATE WS-2320-DAYS-LATE
                 WHEN 0
                    MOVE ZEROS TO WS-2320-LPO-REDUCTION-PCT
                 WHEN <= 10
                    COMPUTE WS-2320-LPO-REDUCTION-PCT =
                       WS-2320-DAYS-LATE * .01
                    END-COMPUTE
                 WHEN <= 20
                    COMPUTE WS-2320-LPO-REDUCTION-PCT =
                       ((WS-2320-DAYS-LATE - 10) * .03) + .10
                    END-COMPUTE
                 WHEN > 20
                    MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                    MOVE 11105 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
                    MOVE WS-LITERAL-DT-PLANTED
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2320-INPUT-DATE-PLANTED
                      TO WS-8000-BAD-DATA1
                    STRING 'LATE DT = '
                       DELIMITED BY SIZE
                       WS-2320-DIS-FINAL-PLANT-DATE
                       DELIMITED BY SIZE
                       ', MUST BE <= 20 DAYS LATE'
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 2320 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-EVALUATE
              GO TO 2320-COMPUTE-LPO-PCT-EXIT
           END-IF

      ****************************************************************
      * DETERMINE CORRECT LATE PLANTING REDUCTION - CANOLA
      ****************************************************************
      *          15 DAY LATE PLANTING FOR CANOLA
      *           MINNESOTA AND NORT DAKOTA ONLY
      *           ALL OTHER STATES ARE 25 DAYS

           IF WS-2320-CROP-CD = WS-LITERAL-CANOLA AND
              (WS-2320-RATE-STATE = WS-LITERAL-MINNESOTA OR
               WS-2320-RATE-STATE = WS-LITERAL-NORTH-DAKOTA)
              EVALUATE WS-2320-DAYS-LATE
                 WHEN 0
                    MOVE ZEROS TO WS-2320-LPO-REDUCTION-PCT
                 WHEN <= 05
                    COMPUTE WS-2320-LPO-REDUCTION-PCT =
                       WS-2320-DAYS-LATE * .02
                    END-COMPUTE
                 WHEN <= 15
                    COMPUTE WS-2320-LPO-REDUCTION-PCT =
                       ((WS-2320-DAYS-LATE - 05) * .03) + .10
                    END-COMPUTE
                 WHEN > 15
                    MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                    MOVE 11105 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
                    MOVE WS-LITERAL-DT-PLANTED
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2320-INPUT-DATE-PLANTED
                      TO WS-8000-BAD-DATA1
                    STRING 'LATE DT = '
                       DELIMITED BY SIZE
                       WS-2320-DIS-FINAL-PLANT-DATE
                       DELIMITED BY SIZE
                       ', MUST BE <= 15 DAYS LATE'
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 2320 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-EVALUATE
              GO TO 2320-COMPUTE-LPO-PCT-EXIT
           END-IF

      ****************************************************************
      * DETERMINE CORRECT LATE PLANTING REDUCTION - CROP LIST #1
      ****************************************************************
      *       25 DAY LATE PLANTING CROP OR SPRING WHEAT
           IF (WS-2320-CROP-CD = WS-LITERAL-CANOLA AND
               WS-2320-RATE-STATE <> WS-LITERAL-MINNESOTA AND
               WS-2320-RATE-STATE <> WS-LITERAL-NORTH-DAKOTA) OR
               WS-2320-CROP-CD = WS-LITERAL-SUGAR-BEETS OR
               WS-2320-CROP-CD = WS-LITERAL-SWEET-CORN OR
               WS-2320-CROP-CD = WS-LITERAL-OATS OR
               WS-2320-CROP-CD = WS-LITERAL-RICE OR
               WS-2320-CROP-CD = WS-LITERAL-COTTON OR
               WS-2320-CROP-CD = WS-LITERAL-FLAX OR
               WS-2320-CROP-CD = WS-LITERAL-CORN OR
               WS-2320-CROP-CD = WS-LITERAL-HYBRID-SORGHUM-SEED OR
               WS-2320-CROP-CD = WS-LITERAL-GRAIN-SORGHUM OR
               WS-2320-CROP-CD = WS-LITERAL-HYBRID-CORN-SEED OR
               WS-2320-CROP-CD = WS-LITERAL-SUNFLOWERS OR
               WS-2320-CROP-CD = WS-LITERAL-SOYBEANS OR
               WS-2320-CROP-CD = WS-LITERAL-BARLEY OR
               WS-2320-CROP-CD = WS-LITERAL-RYE OR
              (WS-2320-CROP-CD = WS-LITERAL-WHEAT AND
               WS-2320-SEED-CYCLE-CD = WS-LITERAL-SPRING)

              EVALUATE WS-2320-DAYS-LATE
                 WHEN 0
                    MOVE ZEROS TO WS-2320-LPO-REDUCTION-PCT
                 WHEN <= 10
                    COMPUTE WS-2320-LPO-REDUCTION-PCT =
                       WS-2320-DAYS-LATE * .01
                    END-COMPUTE
                 WHEN <= 25
                    COMPUTE WS-2320-LPO-REDUCTION-PCT =
                       ((WS-2320-DAYS-LATE - 10) * .02) + .10
                    END-COMPUTE
                 WHEN > 25
                    MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                    MOVE 11105 TO WS-8000-ERROR-CODE
                    MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
                    MOVE WS-LITERAL-DT-PLANTED
                      TO WS-8000-FIELD-NAME1
                    MOVE WS-2320-INPUT-DATE-PLANTED
                      TO WS-8000-BAD-DATA1
                    STRING 'LATE DT = '
                       DELIMITED BY SIZE
                       WS-2320-DIS-FINAL-PLANT-DATE
                       DELIMITED BY SIZE
                       ', MUST BE <= 25 DAYS LATE'
                       DELIMITED BY SIZE
                       INTO WS-8000-CORR-DATA1
                    END-STRING
                    MOVE 2320 TO WS-8000-PARAGRAPH-NO
                    PERFORM 8000-RECORD-TRAN-ERROR
                       THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-EVALUATE
              GO TO 2320-COMPUTE-LPO-PCT-EXIT
           END-IF

      ****************************************************************
      * DETERMINE CORRECT LATE PLANTING REDUCTION - CROP LIST #2
      ****************************************************************
      *          20 DAY LATE PLANTING CROPS EXCEPT FOR MILLET
      *          MILLET PROCESSING IS HANDLED SEPARATELY

           IF (WS-2320-CROP-CD = WS-LITERAL-ONIONS OR
               WS-2320-CROP-CD = WS-LITERAL-POPCORN OR
               WS-2320-CROP-CD = WS-LITERAL-CANNING-BEANS OR
               WS-2320-CROP-CD = WS-LITERAL-DRY-BEANS OR
               WS-2320-CROP-CD = WS-LITERAL-SAFFLOWER OR
               WS-2320-CROP-CD = WS-LITERAL-GREEN-PEAS OR
               WS-2320-CROP-CD = WS-LITERAL-DRY-PEAS OR
               WS-2320-CROP-CD = WS-LITERAL-TOBACCO OR
               WS-2320-CROP-CD = WS-LITERAL-FLUE-CURED-TOBACCO OR
               WS-2320-CROP-CD = WS-LITERAL-FIRE-CURED-TOBACCO OR
               WS-2320-CROP-CD = WS-LITERAL-BURLEY-TOBACCO OR
               WS-2320-CROP-CD = WS-LITERAL-MARYLAND-TOBACCO OR
               WS-2320-CROP-CD = WS-LITERAL-DARK-AIR-TOBACCO OR
               WS-2320-CROP-CD = WS-LITERAL-CIGAR-FILL-TOBACCO OR
               WS-2320-CROP-CD = WS-LITERAL-CIGAR-BINDR-TOBACCO OR
               WS-2320-CROP-CD = WS-LITERAL-CIGAR-WRAPR-TOBACCO OR
               WS-2320-CROP-CD = WS-LITERAL-PEANUTS OR
               WS-2320-CROP-CD = WS-LITERAL-POTATOES OR
               WS-2320-CROP-CD = WS-LITERAL-TOMATOES)

              EVALUATE WS-2320-DAYS-LATE
                WHEN ZEROS
                   MOVE ZEROS TO WS-2320-LPO-REDUCTION-PCT
                WHEN <= 5
                   MOVE .10 TO WS-2320-LPO-REDUCTION-PCT
                WHEN <= 10
                   MOVE .20 TO WS-2320-LPO-REDUCTION-PCT
                WHEN <= 15
                   MOVE .30 TO WS-2320-LPO-REDUCTION-PCT
                WHEN <= 20
                   MOVE .40 TO WS-2320-LPO-REDUCTION-PCT
                WHEN > 20
                   MOVE WS-LITERAL-IF  TO WS-8000-ERROR-TYPE
                   MOVE 11105 TO WS-8000-ERROR-CODE
                   MOVE WS-LITERAL-YES TO ERROR-DT-PLANTED
                   MOVE WS-LITERAL-DT-PLANTED TO WS-8000-FIELD-NAME1
                   MOVE WS-2320-INPUT-DATE-PLANTED TO WS-8000-BAD-DATA1
                   STRING 'LATE DT = '
                      DELIMITED BY SIZE
                      WS-2320-DIS-FINAL-PLANT-DATE
                      DELIMITED BY SIZE
                      ', MUST BE <= 20 DAYS LATE'
                      DELIMITED BY SIZE
                      INTO WS-8000-CORR-DATA1
                   END-STRING
                   MOVE 2320 TO WS-8000-PARAGRAPH-NO
                   PERFORM 8000-RECORD-TRAN-ERROR
                      THRU 8000-RECORD-TRAN-ERROR-EXIT
              END-EVALUATE
           END-IF.

       2320-COMPUTE-LPO-PCT-EXIT.
           EXIT.

