      ***************************************************************
      * File:      IF2500.CBL
      * Author:    Laura Dittamo/Mike Ray
      * Date:      01/29/96
      * Purpose:
      *    This routine determines whether each newly submitted type
      *    11 transaction is on time or late.  It calculates the
      *    weeks late when no corresponding accepted 11 exists.
      *
      *   The First Submission Flag is set for each type 11 which is
      *   being submitted for the first time.
      *   When a policy includes more than one 'first time submission' crop,
      *   the latest extended Acreage Reporting Date is determined for
      *   the crops on the policy.  This value is stored in the
      *   current variable WS-0005-LATEST-EXTENDED-ARD.  Each 'new' Type 11
      *   that is processed will use the latest Acreage Reporting Date
      *   found for the group as well as the other late filed acreage info:
      *   WS-0005-LATEST-EXTENDED-ARD, WS-0005-LATEST-ARD,
      *   WS-0005-REDUCTION-WEEKS, and WS-0005-WEEKS-LATE to update the
      *   associated Type 11 Late Filed Acreage ISAM.
      *
      *   Another module which is performed during process policy change
      *   (3200-PROCESS-HELD-POLICY) updates the accepted date
      *   information.  The Late Filed Date, Acreage Reporting Date and
      *   Reduction Weeks will also be updated if the crop with the
      *   latest Acreage Reporting Date is processed after the
      *   current Type 11's crop has been written to the Type 11 ISAM.
      *
      *   Before each Type 11 is written to the accepted or rejected
      *   transaction file, 3200-PROCESS-HELD-POLICY determines whether
      *   this is the first submission for the Type 11 record.  If
      *   this Type 11 is a first time submission, the Weeks Late field
      *   is set to WS-0005-WEEKS-LATE.  Otherwise, the Weeks Late is
      *   written to the accepted or rejected file with the value
      *   determined for the individual transaction in
      *   2500-DETERMINE-WEEKS-LATE.
      *
      *  Modifications
      *
      *  11/05/97  Use RATE state & county instead of LOCATION.  jlh.
      ***************************************************************

       2500-DETERMINE-WEEKS-LATE.

      $IF DEBUG-SW DEFINED
           DISPLAY '2500-DETERMINING WEEKS LATE'
           UPON CONSOLE
      $END

      **********************************************
      *       INITIALIZE LOCAL VARIABLES           *
      **********************************************
           INITIALIZE WS-2500-WORK
           INITIALIZE WS-2500-TYPE-11-DATES-WORK
           INITIALIZE WS-2500-OUTPUT

      **********************************************
      *            CHECK PRE-CONDITIONS            *
      **********************************************
           IF ERROR-REINSURE-YR = WS-LITERAL-YES OR
              ERROR-RO = WS-LITERAL-YES OR
              ERROR-rate-STATE = WS-LITERAL-YES OR
              ERROR-INSUR-PLAN-CD = WS-LITERAL-YES OR
              ERROR-DT-PLANTED = WS-LITERAL-YES OR
              ERROR-CPNY-CNTY = WS-LITERAL-YES OR
              ERROR-POLICY-NO = WS-LITERAL-YES OR
              ERROR-CROP-YR = WS-LITERAL-YES OR
              ERROR-REC-TYPE = WS-LITERAL-YES OR
              ERROR-CROP-CD = WS-LITERAL-YES OR
              ERROR-CROP-TYPE = WS-LITERAL-YES OR
              ERROR-rate-CouNTY = WS-LITERAL-YES OR
              ERROR-GUAR-RED-FLG = WS-LITERAL-YES OR
              ERROR-GUAR-RED-PCT = WS-LITERAL-YES OR
              ERROR-FCIC-CTRL-DT = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-WEEKS-LATE
              GO TO 2500-DETERMINE-WEEKS-LATE-EXIT
           END-IF

           IF WS-0004-BATCH-NO = ZERO
              MOVE WS-LITERAL-YES TO ERROR-WEEKS-LATE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-0004-BATCH-NO' TO WS-8000-FIELD-NAME1
              MOVE ZEROS TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 2500 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2500-DETERMINE-WEEKS-LATE-EXIT
           END-IF

           IF WS-0004-TRAN-SEQ-NO IS EQUAL ZEROS
              MOVE WS-LITERAL-YES TO ERROR-WEEKS-LATE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-0004-TRAN-SEQ' TO WS-8000-FIELD-NAME1
              MOVE ZEROS TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 2500 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2500-DETERMINE-WEEKS-LATE-EXIT
           END-IF

           IF WS-0004-REINS-YR IS EQUAL ZEROS
              MOVE WS-LITERAL-YES TO ERROR-WEEKS-LATE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 042 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-0004-REINS-YR' TO WS-8000-FIELD-NAME1
              MOVE ZEROS TO WS-8000-BAD-DATA1
              MOVE '> ZERO' TO WS-8000-CORR-DATA1
              MOVE 2500 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2500-DETERMINE-WEEKS-LATE-EXIT
           END-IF

      **************************************************
      *   DETERMINE WHETHER THIS TYPE 11 HAS BEEN      *
      *   SUBMITTED PREVIOUSLY.  LATE DETERMINATION    *
      *   IS ONLY DONE FOR TYPE 11S WHICH ARE NOT      *
      *   MARKED AS ACCEPTED IN THE TYPE 11 DATES FILE.*
      **************************************************

      $IF DEBUG-SW DEFINED
          DISPLAY '2500-LOCATING PREVIOUSLY SUBMITTED 11'
          UPON CONSOLE
      $END

      $IF DATABASE-SW DEFINED
           DISPLAY 'NO DATABASE LOOKUP FOR TYPE 11 DATES IMPLEMENTED!'
           UPON CONSOLE.
      $END

      $IF ISAM-SW DEFINED

           INITIALIZE WS-7565-INPUT-KEY
           MOVE WS-2500-REPORTING-ORG TO WS-7565-INPUT-REPORTING-ORG
           MOVE WS-2500-RATE-STATE TO WS-7565-INPUT-rate-STATE
           MOVE WS-2500-COMPANY-COUNTY TO WS-7565-INPUT-COMPANY-COUNTY
           MOVE WS-2500-POLICY-NUM TO WS-7565-INPUT-POLICY-NUM
           MOVE WS-2500-CROP-YEAR TO WS-7565-INPUT-CROP-YEAR
           MOVE WS-2500-CROP-CD TO WS-7565-INPUT-CROP-CD
           MOVE WS-2500-INSURANCE-PLAN-ID
             TO WS-7565-INPUT-INSURANCE-PLAN
           MOVE WS-2500-RATE-COUNTY TO WS-7565-INPUT-RATE-COUNTY
           MOVE WS-2500-SEED-CYCLE TO WS-7565-INPUT-SEED-CYCLE
           PERFORM 7565-LOOKUP-TYPE-11-DATES
              THRU 7565-LOOKUP-TYPE-11-DATES-EXIT

           IF MATCH-FOUND-7565
              MOVE WS-7565-TYPE-11-DATES-REC
                TO WS-2500-TYPE-11-DATES-WORK
      *      ** RESET THE VALUE OF LOCATION COUNTY WITH THE INPUT 11'S
      *      ** VALUE IF THE RECORD FOUND HAS LOCATION COUNTY = 999.
      *      ** THIS LOGIC CAN BE REMOVED WHEN ALL OF THE DATA MIGRATED
      *      ** FROM THE IBM IS NO LONGER NECESSARY
              IF WS-2500-WORK-RATE-COUNTY = 999
                 MOVE WS-2500-RATE-COUNTY
                   TO WS-2500-WORK-RATE-COUNTY
              END-IF

              IF WS-2500-WORK-ACPT-DATE > ZEROS
      *      ** THIS EDIT IS UNNECCESARY.  IF A TYPE 11 HAS ALREADY BEEN
      *      ** ACCEPTED FOR THIS POLICY AND CROP, USE THE REDUCTION
      *      ** WEEKS SETTING FROM THE TYPE 11 ISAM TO SET WEEKS LATE
      *      ** FOR THIS TYPE 11.  IF REDUCTION WEEKS = ZEROS, WEEKS
      *      ** LATE IS SET TO ZEROS.  IF REDUCTION WEEKS > ZEROS, ADD
      *      ** 12 TO THIS NUMBER AND SET WEEKS LATE WITH THE RESULTING
      *      ** SUM.

      $IF DEBUG-SW DEFINED
           DISPLAY 'MATCH FOUND ACCEPT DATE: ', WS-2500-WORK-ACPT-DATE
           UPON CONSOLE
      $END

      *      ** WEEKS LATE IS RECALCULATED USING REDUCTION WEEKS ON
      *      ** THE TYPE 11 ISAM.  IF REDUCTION WEEKS > ZEROS,
      *      ** WEEKS LATE IS REDUCTION WEEKS + 12
      *
      *      ** WEEKS LATE IS RECALCULATED AND PLACED ON THE INPUT TRANS
                 IF WS-2500-WORK-REDUCTION-WEEKS > ZEROS
                    ADD +12 TO WS-2500-WORK-REDUCTION-WEEKS
                 END-IF
                 MOVE WS-2500-WORK-REDUCTION-WEEKS
                   TO WS-2500-WEEKS-LATE
                 GO TO 2500-DETERMINE-WEEKS-LATE-EXIT
              END-IF
           ELSE
      **      *******************************************************
      **      * NO MATCHING T11 ISAM WAS FOUND.  THIS MEANS THAT    *
      **      * THIS IS THE FIRST SUBMISSION FOR THE CURRENT        *
      **      * TYPE 11 RECORD.  WS-2500-FIRST-SUBMISSION-FLG IS SET*
      **      * TO 'YES'.  THIS FLAG WILL BE USED IN IR3200 TO      *
      **      * DETERMINE WHETHER TO UPDATE THE RECORD WITH         *
      **      * THE WEEKS LATE DETERMINED FOR THE POLICY.           *
      **      *******************************************************
      $IF DEBUG-SW DEFINED
           DISPLAY '2500-NO MATCHING TYPE 11 ISAM RECORD FOUND'
           UPON CONSOLE
      $END
              MOVE WS-LITERAL-YES TO WS-2500-FIRST-SUBMISSION-FLG
           END-IF

      *      ** WEEKS LATE IS DETERMINED WHEN THE MATCHING 11 HAS NOT
      *      ** BEEN ACCEPTED OR THERE IS NO MATCHING 11 ON THE ISAM
           PERFORM 2500-GET-ARD
              THRU 2500-GET-ARD-EXIT

           IF ERROR-ACREAGE-RPT-DT = WS-LITERAL-YES
              MOVE WS-LITERAL-YES TO ERROR-WEEKS-LATE
              GO TO 2500-DETERMINE-WEEKS-LATE-EXIT
           END-IF

      **********************************************
      *            CHECK POST-CONDITIONS           *
      **********************************************
           PERFORM 2500-CHECK-ARD-DATA
              THRU 2500-CHECK-ARD-DATA-EXIT

           IF ERROR-WEEKS-LATE = WS-LITERAL-YES
              GO TO 2500-DETERMINE-WEEKS-LATE-EXIT
           END-IF

      **********************************************
      *           NORMAL PROCESSING                *
      **********************************************

           PERFORM 2500-EXTEND-ARD-12-WKS
              THRU 2500-EXTEND-ARD-12-WKS-EXIT

      *****************************************************
      *       DETERMINE IF THE TRANSACTION IS LATE        *
      *****************************************************
           INITIALIZE WS-0560-INPUT
           MOVE WS-2500-FCIC-CTRL-DT TO WS-0560-INPUT-DATE1
           MOVE WS-2500-EXTENDED-ARD TO WS-0560-INPUT-DATE2

           PERFORM 0560-COMPARE-DATES-6
              THRU 0560-COMPARE-DATES-6-EXIT

      **********************************************
      *            CHECK POST-CONDITION            *
      **********************************************

           IF NOT VALID-RESULT-FLAG-0560
              MOVE 2500 TO WS-8020-PARAGRAPH-NO
              MOVE 90004 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-0560-RESULT-FLAG' TO WS-8020-FIELD-NAME
              MOVE WS-0560-RESULT-FLAG TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

           IF DATE1-GREATER-THAN-DATE2-0560
      *    THE TRANSACTION IS LATE, DETERMINE THE NUMBER OF
      *    REDUCTION WEEKS

      $IF DEBUG-SW DEFINED
           DISPLAY 'THIS TRANSACTION IS LATE',
           DISPLAY 'FCIC CONTROL DATE ', WS-2500-FCIC-CTRL-DT,
           DISPLAY 'IS LATER THAN EXTENDED ARD ', WS-2500-EXTENDED-ARD
           UPON CONSOLE
      $END

      * FIND THE CORRESPONDING JULIAN DATES (YYYYDDD) FOR THE
      * FCIC CONTROL DATE AND EXTENDED ACREAGE REPORTING DATE
              INITIALIZE WS-0550-INPUT-DATE
              MOVE WS-0004-REINS-YR TO WS-0550-INPUT-FULL-YEAR
              MOVE WS-2500-FCIC-YEAR TO WS-0550-INPUT-YEAR
              MOVE WS-2500-FCIC-MONTH TO WS-0550-INPUT-MONTH
              MOVE WS-2500-FCIC-DAY TO WS-0550-INPUT-DAY
              PERFORM 0550-GET-JULIAN-DATE
                 THRU 0550-GET-JULIAN-DATE-EXIT

              MOVE WS-0550-OUTPUT-JULIAN-DATE
                TO WS-2500-JUL-FCIC-CTRL-DT

              INITIALIZE WS-0550-INPUT-DATE
              MOVE WS-0004-REINS-YR TO WS-0550-INPUT-FULL-YEAR
              MOVE WS-2500-EXT-ARD-YEAR TO WS-0550-INPUT-YEAR
              MOVE WS-2500-EXT-ARD-MONTH TO WS-0550-INPUT-MONTH
              MOVE WS-2500-EXT-ARD-DAY TO WS-0550-INPUT-DAY
              PERFORM 0550-GET-JULIAN-DATE
                 THRU 0550-GET-JULIAN-DATE-EXIT

              MOVE WS-0550-OUTPUT-JULIAN-DATE
                TO WS-2500-JUL-EXTENDED-ARD

      *    DETERMINE THE NUMBER OF DAYS LATE

              IF WS-2500-JUL-FCIC-YEAR = WS-2500-JUL-ARD-YEAR
                 COMPUTE WS-2500-TOT-DAYS-LATE =
                    WS-2500-JUL-FCIC-DAY - WS-2500-JUL-ARD-DAY
              ELSE
      *    THE FCIC YEAR IS GREATER THAN THE ARD YEAR.
      *    FIND THE NUMBER OF DAYS IN THE ARD YEAR.  IF FCIC DAYS >
      *    ARD DAYS ADD THE DIFFERENCE TO DAYS IN YEAR.  OTHERWISE,
      *    SUBTRACT THE DIFFERENCE FROM DAYS IN YEAR.

                 MOVE WS-2500-JUL-ARD-YEAR TO WS-0525-INPUT-YEAR
                 PERFORM 0525-DETERMINE-IF-LEAP-YR
                    THRU 0525-DETERMINE-IF-LEAP-YR-EXIT

                 IF LEAP-YEAR-0525
                    MOVE 366 TO WS-2500-DAYS-IN-YEAR
                 ELSE
                    MOVE 365 TO WS-2500-DAYS-IN-YEAR
                 END-IF

                 COMPUTE WS-2500-DAYS-LATE =
                    WS-2500-JUL-FCIC-DAY - WS-2500-JUL-ARD-DAY

                 COMPUTE WS-2500-TOT-DAYS-LATE =
                    WS-2500-DAYS-IN-YEAR + WS-2500-DAYS-LATE
              END-IF

      *    DETERMINE THE NUMBER OF WEEKS LATE
              IF WS-2500-TOT-DAYS-LATE < 7
                 MOVE 1 TO WS-2500-WEEKS-LATE
              ELSE
                 COMPUTE WS-2500-WORK-WEEKS-LATE-DEC ROUNDED =
                         (WS-2500-TOT-DAYS-LATE / 7)

                 IF WS-2500-PARTIAL-WEEKS-LATE > 0
                    ADD +1 TO WS-2500-TOT-WEEKS-LATE
                    MOVE WS-2500-TOT-WEEKS-LATE
                      TO WS-2500-WEEKS-LATE
                 END-IF
              END-IF
           ELSE
      *    THE TRANSACTION IS ON TIME, INITIALIZE THE NUMBER OF
      *    WEEKS LATE.
              MOVE 0 TO WS-2500-WEEKS-LATE
           END-IF.
      $END

      $IF DEBUG-SW DEFINED
           DISPLAY 'JULIAN FCIC DT  : ', WS-2500-JUL-FCIC-CTRL-DT
           UPON CONSOLE
           DISPLAY 'JULIAN ARD      : ', WS-2500-JUL-EXTENDED-ARD
           UPON CONSOLE
           DISPLAY 'DAYS LATE       : ', WS-2500-DAYS-LATE
           UPON CONSOLE
           DISPLAY 'TOTAL DAYS LATE : ', WS-2500-TOT-DAYS-LATE
           UPON CONSOLE
           DISPLAY 'WEEKS LATE      : ', WS-2500-WEEKS-LATE
           UPON CONSOLE
      $END

      **   CALCULATE THE VALUE OF REDUCTION WEEKS
      **   1 - 12 WEEKS LATE = 0 REDUCTION WEEKS
      **   13 WEEKS LATE = 1 REDUCTION WEEK
      **   14 WEEKS LATE = 2 REDUCTION WEEKS
      **   15 WEEKS LATE = 3 REDUCTION WEEKS
      **   SAME CONVERSION IS DONE FOR 13 - 20 WEEKS LATE
      **   REDUCTION WEEKS CAPS AT 18
      **   21 - 99 WEEKS LATE = 18 REDUCTION WEEKS

           IF WS-2500-WEEKS-LATE > 0
              IF WS-2500-WEEKS-LATE > 20
                 MOVE 18 TO WS-2500-REDUCTION-WEEKS
              ELSE IF WS-2500-WEEKS-LATE < 13
                 MOVE ZEROS TO WS-2500-REDUCTION-WEEKS
              ELSE
                 COMPUTE WS-2500-REDUCTION-WEEKS =
                    WS-2500-WEEKS-LATE - 12
              END-IF
           ELSE
              MOVE ZEROS TO WS-2500-REDUCTION-WEEKS
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY 'REDUCTION WEEKS  : ', WS-2500-REDUCTION-WEEKS
           UPON CONSOLE
      $END

           IF MATCH-FOUND-7565
      *    ** A MATCHING TYPE 11 DATES RECORD EXISTS FOR THIS POLICY
      *    ** BUT HAS NOT BEEN ACCEPTED. UPDATE THE EXISTING TYPE 11
      *    ** RECORD.
      $IF DEBUG-SW DEFINED
           DISPLAY '2500-UPDATE THE CORRESPONDING TYPE 11 ISAM RECORD'
           UPON CONSOLE
      $END
              INITIALIZE WS-0980-INPUT-REC
              MOVE WS-2500-TYPE-11-DATES-WORK TO WS-0980-INPUT-REC
              MOVE WS-2500-REDUCTION-WEEKS
                TO WS-0980-REDUCTION-WEEKS
              MOVE WS-2500-EXTENDED-ARD
                TO WS-0980-LATE-FILED-DATE
              MOVE WS-2500-LATEST-ARD TO WS-0980-ACREAGE-RPT-DATE

              PERFORM 0980-WRITE-TYPE-11-DT-REC
                 THRU 0980-WRITE-TYPE-11-DT-REC-EXIT

           ELSE
      **      FOR EACH POLICY, WE ARE STORING THE LATEST ACREAGE REPORTING
      **      DATE FOR CROPS BEING SUBMITTED FOR THE FIRST TIME.

      **      IF THIS TYPE 11'S EXTENDED ARD IS LATER THAN THE LATEST
      **      EXTENDED ARD STORED FOR THE POLICY, REPLACE THE
      **      CURRENT POLICY VALUES WITH THE TYPE 11'S VALUES.
      **
      **      CURRENT POLICY                   TYPE 11
      **      WS-0005-LATEST-EXTENDED-ARD      WS-2500-EXTENDED-ARD
      **      WS-0005-REDUCTION-WEEKS          WS-2500-REDUCTION-WEEKS
      **      WS-0005-WEEKS-LATE               WS-2500-WEEKS-LATE
      **      WS-0005-LATEST-ARD               WS-2500-LATEST-ARD


      **      *****************************************************
      **      * DETERMINE WHETHER THIS TYPE 11'S EXTENDED ARD IS  *
      **      * LATER THAN THE LATEST EXTENDED ARD FOR THE POLICY *
      **      *****************************************************

      *       *** IF THE ACREAGE REPORTING DATE HASN'T BEEN SET YET
      *       *** MOVE THE EXTENDED ARD INTO IT.
              IF WS-0005-LATEST-EXTENDED-ARD = ZEROS
                 MOVE WS-2500-EXTENDED-ARD
                   TO WS-0005-LATEST-EXTENDED-ARD
                 MOVE WS-2500-REDUCTION-WEEKS
                   TO WS-0005-REDUCTION-WEEKS
                 MOVE WS-2500-WEEKS-LATE
                   TO WS-0005-WEEKS-LATE
                 MOVE WS-2500-LATEST-ARD TO WS-0005-LATEST-ARD
              END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY '2500-LFA INFO FOR THE POLICY',
           DISPLAY 'LATEST ARD:      ', WS-0005-LATEST-ARD,
           DISPLAY 'LATEST EXT ARD:  ', WS-0005-LATEST-EXTENDED-ARD,
           DISPLAY 'REDUCTION WEEKS: ', WS-0005-REDUCTION-WEEKS,
           DISPLAY 'WEEKS LATE:      ', WS-0005-WEEKS-LATE
           UPON CONSOLE
      $END

      $IF DEBUG-SW DEFINED
           DISPLAY '2500-DETERMINE IF LFA INFO NEEDS TO BE UPDATED',
           DISPLAY 'COMPARE CURRENT CROP EXTENDED ARD: ',
                    WS-2500-EXTENDED-ARD,
           DISPLAY 'WITH LATEST EXTEND ARD FOR POLICY: ',
                    WS-0005-LATEST-EXTENDED-ARD,
           UPON CONSOLE
      $END
              INITIALIZE WS-0560-INPUT
              MOVE WS-2500-EXTENDED-ARD TO WS-0560-INPUT-DATE1
              MOVE WS-0005-LATEST-EXTENDED-ARD TO WS-0560-INPUT-DATE2
              PERFORM 0560-COMPARE-DATES-6
                 THRU 0560-COMPARE-DATES-6-EXIT

      *    **********************************************
      *    *            CHECK POST-CONDITION            *
      *    **********************************************

              IF NOT VALID-RESULT-FLAG-0560
                 MOVE 2500 TO WS-8020-PARAGRAPH-NO
                 MOVE 90004 TO WS-8020-INT-ERROR-NO
                 MOVE 'WS-0560-RESULT-FLAG' TO WS-8020-FIELD-NAME
                 MOVE WS-0560-RESULT-FLAG TO WS-8020-BAD-DATA
                 MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                 PERFORM 8020-RECORD-INT-ERROR
                    THRU 8020-RECORD-INT-ERROR-EXIT
              END-IF

              IF DATE1-GREATER-THAN-DATE2-0560
      *       THIS CROP HAS AN EXTENDED ARD WHICH IS LATER THAN ANY OF
      *       THE CROPS THAT WERE PROCESSED EARLIER FOR THIS POLICY.  THE
      *       EXTENDED ARD FOR THIS TYPE 11 SHOULD UPDATE THE LATEST EXTENDED
      *       ARD FOR THE POLICY.
                 MOVE WS-2500-EXTENDED-ARD
                   TO WS-0005-LATEST-EXTENDED-ARD
                 MOVE WS-2500-REDUCTION-WEEKS
                   TO WS-0005-REDUCTION-WEEKS
                 MOVE WS-2500-WEEKS-LATE
                   TO WS-0005-WEEKS-LATE
                 MOVE WS-2500-LATEST-ARD TO WS-0005-LATEST-ARD
      $IF DEBUG-SW DEFINED
           DISPLAY 'THIS CROP HAS FURTHER EXTENDED LFA INFO',
           DISPLAY '2500-UPDATE LFA INFO FOR THE POLICY',
           DISPLAY 'LATEST ARD:      ', WS-0005-LATEST-ARD,
           DISPLAY 'LATEST EXT ARD:  ', WS-0005-LATEST-EXTENDED-ARD,
           DISPLAY 'REDUCTION WEEKS: ', WS-0005-REDUCTION-WEEKS,
           DISPLAY 'WEEKS LATE:      ', WS-0005-WEEKS-LATE
           UPON CONSOLE
      $END
              ELSE
      **      SET THE TRANSACTION'S WEEKS LATE TO THE WEEKS LATE
      **      FOR THE POLICY
      $IF DEBUG-SW DEFINED
           DISPLAY 'CURRENT LFA INFO STANDS',
           UPON CONSOLE
      $END
                 MOVE WS-0005-WEEKS-LATE TO WS-2500-WEEKS-LATE
              END-IF


      **      THE LATEST EXTENDED ARD FOR THE BATCH IS USED TO UPDATE
      **      THE TYPE 11 ISAM.
      *       ** NO TYPE 11 DATES RECORD EXISTS FOR THIS POLICY
      *       ** AND CROP, ESTABLISH A NEW TYPE 11 RECORD
      $IF DEBUG-SW DEFINED
           DISPLAY '2500-ESTABLISH NEW TYPE 11 ISAM RECORD'
           UPON CONSOLE
      $END
              MOVE WS-2500-REPORTING-ORG TO WS-0980-REPORTING-ORG
              MOVE WS-2500-RATE-STATE TO WS-0980-RATE-STATE
              MOVE WS-2500-COMPANY-COUNTY
                TO WS-0980-COMPANY-COUNTY
              MOVE WS-2500-POLICY-NUM TO WS-0980-POLICY-NUM
              MOVE WS-2500-CROP-YEAR TO WS-0980-CROP-YEAR
              MOVE WS-2500-CROP-CD TO WS-0980-CROP-CD
              MOVE WS-2500-INSURANCE-PLAN-ID
                   TO WS-0980-INSURANCE-PLAN-ID
              MOVE WS-2500-RATE-COUNTY
                TO WS-0980-RATE-COUNTY
              MOVE WS-2500-SEED-CYCLE TO WS-0980-SEED-CYCLE
              MOVE WS-0005-LATEST-EXTENDED-ARD
                TO WS-0980-LATE-FILED-DATE
              MOVE WS-0005-REDUCTION-WEEKS
                TO WS-0980-REDUCTION-WEEKS
              MOVE WS-0005-LATEST-ARD
                TO WS-0980-ACREAGE-RPT-DATE
              MOVE WS-2500-FCIC-CTRL-DT TO WS-0980-ORIG-SUB-DATE
              MOVE WS-0004-BATCH-NO TO WS-0980-ORIG-SUB-BATCH-NUM
              MOVE WS-0004-TRAN-SEQ-NO
                TO WS-0980-ORIG-SUB-TRANS-SEQ-NUM
      **      ACCEPTANCE INFORMATION IS ONLY SET WHEN THE 11 HAS
      **      PASSED ALL VALIDATION
              MOVE ZEROS TO WS-0980-ACCEPTED-DATE
              MOVE ZEROS TO WS-0980-ACCEPTED-TIME
              MOVE ZEROS TO WS-0980-ACCEPTED-BATCH-NUM
              MOVE ZEROS TO WS-0980-ACCEPTED-TRANS-SEQ-NUM
      **      OVERRIDE INFORMATION IS NOT SET BY NORMAL PROCESSING
              MOVE SPACES TO WS-0980-OVERRIDE-APPROVAL-CD
              MOVE SPACES TO WS-0980-OVERRIDE-USER-ID
              MOVE ZEROS TO WS-0980-OVERRIDE-DATE
              PERFORM 0980-WRITE-TYPE-11-DT-REC
                 THRU 0980-WRITE-TYPE-11-DT-REC-EXIT
           END-IF.


       2500-DETERMINE-WEEKS-LATE-EXIT.
           EXIT.


       2500-GET-ARD.

      $IF DEBUG-SW DEFINED
           DISPLAY '2500-LOCATING ACREAGE REPORTING DATE'
           UPON CONSOLE
      $END


      $IF ISAM-SW DEFINED
           INITIALIZE WS-7515-INPUT-KEY
           MOVE WS-2500-CROP-YEAR TO WS-7515-INPUT-CROP-YR
           MOVE WS-2500-RATE-STATE TO WS-7515-INPUT-STATE-CD
           MOVE WS-2500-RATE-COUNTY TO WS-7515-INPUT-COUNTY-CD
           MOVE WS-2500-CROP-CD TO WS-7515-INPUT-CROP-CD
           MOVE WS-2500-INSURANCE-PLAN-ID
             TO WS-7515-INPUT-INSURANCE-PLAN
           MOVE WS-2500-PRACTICE-CD TO WS-7515-INPUT-PRACTICE-CD
      *    IF WS-2500-TYPE-CD = SPACES OR
      *       WS-2500-TYPE-CD = ZEROS
      *       MOVE 997 TO WS-7515-INPUT-TYPE-CD
      *     ELSE
              MOVE WS-2500-TYPE-CD TO WS-7515-INPUT-TYPE-CD
      *     END-IF
           PERFORM 7515-LOOKUP-ADM3
              THRU 7515-LOOKUP-ADM3-EXIT

           IF MATCH-FOUND-7515
      *       *** GET ACREAGE REPORTING DATE
              IF WS-7515-MOD-ACREAGE-REPORTING > ZEROS
                 MOVE WS-7515-MOD-ACREAGE-REPORTING
                   TO WS-2500-LATEST-ARD
              ELSE
                 IF WS-7515-ACREAGE-REPORTING > ZEROS
                    MOVE WS-7515-ACREAGE-REPORTING
                      TO WS-2500-LATEST-ARD
                 ELSE
                    MOVE 2500 TO WS-8020-PARAGRAPH-NO
                    MOVE 90010 TO WS-8020-INT-ERROR-NO
                    MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
                    MOVE 'ACREAGE RPTG DT' TO WS-8020-FIELD-NAME
                    PERFORM 8020-RECORD-INT-ERROR
                       THRU 8020-RECORD-INT-ERROR-EXIT
                 END-IF
              END-IF
           ELSE
              MOVE 11009 TO WS-8000-ERROR-CODE
              MOVE WS-LITERAL-IF TO WS-8000-ERROR-TYPE
              MOVE WS-LITERAL-YES TO ERROR-ACREAGE-RPT-DT
              MOVE WS-LITERAL-RATE-STATE TO WS-8000-FIELD-NAME1
              MOVE SPACES TO WS-8000-BAD-DATA1
              MOVE WS-2500-RATE-STATE TO WS-8000-CORR-DATA1
              MOVE WS-LITERAL-rate-CouNTY TO WS-8000-FIELD-NAME2
              MOVE SPACES TO WS-8000-BAD-DATA2
              MOVE ws-2500-rate-county TO WS-8000-CORR-DATA2
              MOVE WS-LITERAL-CROP-CD TO WS-8000-FIELD-NAME3
              MOVE SPACES TO WS-8000-BAD-DATA3
              MOVE WS-2500-CROP-CD TO WS-8000-CORR-DATA3
              MOVE 'DATES' TO WS-8000-TABLE-NAME
              MOVE 2500 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
           END-IF.

      $END

       2500-GET-ARD-EXIT.
           EXIT.


       2500-CHECK-ARD-DATA.

      $IF DEBUG-SW DEFINED
              DISPLAY 'FCIC DT: ', WS-2500-FCIC-CTRL-DT
              UPON CONSOLE
              DISPLAY 'ARD: ', WS-2500-LATEST-ARD
              UPON CONSOLE
      $END

           IF WS-2500-FCIC-CTRL-DT IS NOT NUMERIC
              MOVE WS-LITERAL-YES TO ERROR-WEEKS-LATE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 044 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2500-FCIC-CTRL-DT'
                TO WS-8000-FIELD-NAME1
              MOVE 'NOT NUMERIC' TO WS-8000-BAD-DATA1
              MOVE 'NUMERIC'
                TO WS-8000-CORR-DATA1
              MOVE 2500 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2500-CHECK-ARD-DATA-EXIT
           END-IF

           IF WS-2500-LATEST-ARD IS NOT NUMERIC
              MOVE WS-LITERAL-YES TO ERROR-WEEKS-LATE
              MOVE WS-TRAN-TYPE TO WS-8000-ERROR-TRAN-TYPE
              MOVE 044 TO WS-8000-SHORT-ERROR
              MOVE WS-LITERAL-PR TO WS-8000-ERROR-TYPE
              MOVE 'WS-2500-LATEST-ARD'
                TO WS-8000-FIELD-NAME1
              MOVE 'NOT NUMERIC' TO WS-8000-BAD-DATA1
              MOVE 'NUMERIC'
                TO WS-8000-CORR-DATA1
              MOVE 2500 TO WS-8000-PARAGRAPH-NO
              PERFORM 8000-RECORD-TRAN-ERROR
                 THRU 8000-RECORD-TRAN-ERROR-EXIT
              GO TO 2500-CHECK-ARD-DATA-EXIT
           END-IF

           MOVE WS-2500-FCIC-CTRL-DT TO WS-0515-INPUT-DATE
           PERFORM 0515-VAL-DATE
              THRU 0515-VAL-DATE-EXIT
           IF NOT VALID-DATE-0515
              MOVE 2500 TO WS-8020-PARAGRAPH-NO
              MOVE 90014 TO WS-8020-INT-ERROR-NO
              MOVE WS-LITERAL-FCIC-CTRL-DT TO WS-8020-FIELD-NAME
              MOVE WS-2500-FCIC-CTRL-DT TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF

      $IF DEBUG-SW DEFINED
           DISPLAY '2500-VALIDATING ARD'
           UPON CONSOLE
      $END

           MOVE WS-2500-LATEST-ARD TO WS-0515-INPUT-DATE
           PERFORM 0515-VAL-DATE
              THRU 0515-VAL-DATE-EXIT
           IF NOT VALID-DATE-0515
              MOVE 2500 TO WS-8020-PARAGRAPH-NO
              MOVE 90014 TO WS-8020-INT-ERROR-NO
              MOVE 'WS-ACREAGE-RPTG-DT' TO WS-8020-FIELD-NAME
              MOVE WS-2500-LATEST-ARD TO WS-8020-BAD-DATA
              MOVE WS-LITERAL-YES TO WS-8020-ABORT-PROGRAM
              PERFORM 8020-RECORD-INT-ERROR
                 THRU 8020-RECORD-INT-ERROR-EXIT
           END-IF.

       2500-CHECK-ARD-DATA-EXIT.
           EXIT.


       2500-EXTEND-ARD-12-WKS.

      $IF DEBUG-SW DEFINED
           DISPLAY 'EXTENDING ARD 12 WEEKS'
           UPON CONSOLE
      $END

      ******************************************************************
      * ADD 12 WEEKS, 84 DAYS, TO THE ACREAGE REPORTING DATE           *
      ******************************************************************
           MOVE 84 TO WS-0530-INPUT-DAYS-TO-ADD
           MOVE WS-2500-LATEST-ARD TO WS-0530-INPUT-DATE
      $IF DEBUG-SW DEFINED
           DISPLAY 'ARD: ', WS-0530-INPUT-DATE
           UPON CONSOLE
      $END

           PERFORM 0530-ADD-DAYS-TO-DATE
              THRU 0530-ADD-DAYS-TO-DATE-EXIT
           MOVE WS-0530-OUTPUT-DATE TO WS-2500-EXTENDED-ARD

      $IF DEBUG-SW DEFINED
           DISPLAY 'EXTENDED ARD: ', WS-2500-EXTENDED-ARD
           UPON CONSOLE
      $END

      *****************************************************
      *      MOVE EXTENDED ARD TO NEXT SATURDAY           *
      *****************************************************
           MOVE WS-0004-REINS-YR TO WS-0535-INPUT-FULL-YEAR
           MOVE WS-2500-EXT-ARD-YEAR TO WS-0535-INPUT-YEAR
           MOVE WS-2500-EXT-ARD-MONTH TO WS-0535-INPUT-MONTH
           MOVE WS-2500-EXT-ARD-DAY TO WS-0535-INPUT-DAY
           PERFORM 0535-GET-DAY-OF-WEEK
              THRU 0535-GET-DAY-OF-WEEK-EXIT

      *       ****************************************************
      *       *  IF THE DAY OF THE WEEK IS NOT SATURDAY,  THE ACRG
      *       *  RPT DATE MUST BE MOVED TO THE FOLLOWING SATURDAY
      *       *  SUBTRACTING THE DAY-OF-WEEK VALUE FROM 6 GIVES THE
      *       *  CORRECT NUMBER OF DAYS TO ADD TO GET TO SATURDAY
      *       ****************************************************

           IF NOT SATURDAY-0535
      $IF DEBUG-SW DEFINED
           DISPLAY '2500-MOVING DATE TO NEXT SATURDAY'
           UPON CONSOLE
      $END
              MOVE WS-2500-EXTENDED-ARD TO WS-0530-INPUT-DATE
              COMPUTE WS-0530-INPUT-DAYS-TO-ADD =
                  WS-0535-OUTPUT-DAY - 6
              PERFORM 0530-ADD-DAYS-TO-DATE
                 THRU 0530-ADD-DAYS-TO-DATE-EXIT
              MOVE WS-0530-OUTPUT-DATE TO WS-2500-EXTENDED-ARD
           END-IF.

      $IF DEBUG-SW DEFINED
           DISPLAY 'EXTENDED ARD MOVED TO SAT: ', WS-2500-EXTENDED-ARD
           UPON CONSOLE.
      $END

       2500-EXTEND-ARD-12-WKS-EXIT.
           EXIT.





